[Libreoffice-commits] core.git: include/editeng
Noel Grandin
noel at peralex.com
Wed Oct 21 01:32:16 PDT 2015
include/editeng/AccessibleComponentBase.hxx | 61 +--
include/editeng/AccessibleContextBase.hxx | 106 ++----
include/editeng/AccessibleEditableTextPara.hxx | 166 ++++-----
include/editeng/AccessibleImageBullet.hxx | 74 ++--
include/editeng/AccessibleParaManager.hxx | 34 +-
include/editeng/AccessibleSelectionBase.hxx | 16
include/editeng/AccessibleStaticTextBase.hxx | 50 +-
include/editeng/SpellPortions.hxx | 6
include/editeng/UnoForbiddenCharsTable.hxx | 16
include/editeng/acorrcfg.hxx | 8
include/editeng/adjustitem.hxx | 6
include/editeng/borderline.hxx | 8
include/editeng/boxitem.hxx | 14
include/editeng/brushitem.hxx | 4
include/editeng/charreliefitem.hxx | 4
include/editeng/charrotateitem.hxx | 4
include/editeng/charscaleitem.hxx | 4
include/editeng/cmapitem.hxx | 4
include/editeng/crossedoutitem.hxx | 6
include/editeng/editeng.hxx | 32 -
include/editeng/editobj.hxx | 2
include/editeng/editview.hxx | 10
include/editeng/edtdlg.hxx | 2
include/editeng/emphasismarkitem.hxx | 4
include/editeng/escapementitem.hxx | 4
include/editeng/fhgtitem.hxx | 4
include/editeng/flditem.hxx | 32 -
include/editeng/flstitem.hxx | 6
include/editeng/forbiddencharacterstable.hxx | 12
include/editeng/formatbreakitem.hxx | 4
include/editeng/frmdiritem.hxx | 4
include/editeng/fwdtitem.hxx | 4
include/editeng/hangulhanja.hxx | 8
include/editeng/hyphenzoneitem.hxx | 4
include/editeng/justifyitem.hxx | 12
include/editeng/kernitem.hxx | 4
include/editeng/langitem.hxx | 4
include/editeng/lineitem.hxx | 4
include/editeng/lrspitem.hxx | 4
include/editeng/lspcitem.hxx | 4
include/editeng/measfld.hxx | 2
include/editeng/numitem.hxx | 18 -
include/editeng/optitems.hxx | 10
include/editeng/outliner.hxx | 23 -
include/editeng/overflowingtxt.hxx | 3
include/editeng/paravertalignitem.hxx | 4
include/editeng/pmdlitem.hxx | 4
include/editeng/postitem.hxx | 4
include/editeng/protitem.hxx | 4
include/editeng/rsiditem.hxx | 4
include/editeng/shaditem.hxx | 4
include/editeng/sizeitem.hxx | 4
include/editeng/splwrap.hxx | 33 -
include/editeng/svxacorr.hxx | 4
include/editeng/svxrtf.hxx | 8
include/editeng/tstpitem.hxx | 4
include/editeng/twolinesitem.hxx | 4
include/editeng/udlnitem.hxx | 4
include/editeng/ulspitem.hxx | 4
include/editeng/unofdesc.hxx | 10
include/editeng/unofield.hxx | 72 ++--
include/editeng/unoipset.hxx | 20 -
include/editeng/unolingu.hxx | 127 ++-----
include/editeng/unonrule.hxx | 40 +-
include/editeng/unopracc.hxx | 16
include/editeng/unotext.hxx | 422 ++++++++++++-------------
include/editeng/wghtitem.hxx | 4
include/editeng/writingmodeitem.hxx | 6
include/editeng/xmlcnitm.hxx | 4
69 files changed, 784 insertions(+), 837 deletions(-)
New commits:
commit e6424f14f314d2245387aa25909de03440672cdf
Author: Noel Grandin <noel at peralex.com>
Date: Tue Oct 20 14:31:54 2015 +0200
com::sun::star->css in include/editeng
Change-Id: I2a46f2128ef86ea0d692240b968ea52ab8e09dcc
Reviewed-on: https://gerrit.libreoffice.org/19489
Tested-by: Jenkins <ci at libreoffice.org>
Reviewed-by: Noel Grandin <noelgrandin at gmail.com>
diff --git a/include/editeng/AccessibleContextBase.hxx b/include/editeng/AccessibleContextBase.hxx
index 86bf81d..7f414eb 100644
--- a/include/editeng/AccessibleContextBase.hxx
+++ b/include/editeng/AccessibleContextBase.hxx
@@ -53,10 +53,10 @@ struct MutexOwner {mutable ::osl::Mutex maMutex;};
class EDITENG_DLLPUBLIC AccessibleContextBase
: public MutexOwner,
public cppu::WeakComponentImplHelper<
- ::com::sun::star::accessibility::XAccessible,
- ::com::sun::star::accessibility::XAccessibleContext,
- ::com::sun::star::accessibility::XAccessibleEventBroadcaster,
- ::com::sun::star::lang::XServiceInfo
+ css::accessibility::XAccessible,
+ css::accessibility::XAccessibleContext,
+ css::accessibility::XAccessibleEventBroadcaster,
+ css::lang::XServiceInfo
>
{
public:
@@ -73,8 +73,7 @@ public:
};
AccessibleContextBase (
- const ::com::sun::star::uno::Reference<
- ::com::sun::star::accessibility::XAccessible>& rxParent,
+ const css::uno::Reference< css::accessibility::XAccessible>& rxParent,
const sal_Int16 aRole);
virtual ~AccessibleContextBase();
@@ -91,8 +90,8 @@ public:
not applicable.
*/
void CommitChange (sal_Int16 aEventId,
- const ::com::sun::star::uno::Any& rNewValue,
- const ::com::sun::star::uno::Any& rOldValue);
+ const css::uno::Any& rNewValue,
+ const css::uno::Any& rOldValue);
/** Set a new description and, provided that the new name differs from
the old one, broadcast an accessibility event.
@@ -107,7 +106,7 @@ public:
void SetAccessibleDescription (
const OUString& rsDescription,
StringOrigin eDescriptionOrigin)
- throw (::com::sun::star::uno::RuntimeException);
+ throw (css::uno::RuntimeException);
/** Set a new description and, provided that the new name differs from
the old one, broadcast an accessibility event.
@@ -121,7 +120,7 @@ public:
void SetAccessibleName (
const OUString& rsName,
StringOrigin eNameOrigin)
- throw (::com::sun::star::uno::RuntimeException);
+ throw (css::uno::RuntimeException);
/** Set the specified state (turn it on) and send events to all
listeners to inform them of the change.
@@ -165,88 +164,82 @@ public:
The new relation set that replaces the old one.
*/
void SetRelationSet (
- const ::com::sun::star::uno::Reference<
- ::com::sun::star::accessibility::XAccessibleRelationSet>& rxRelationSet)
- throw (::com::sun::star::uno::RuntimeException);
+ const css::uno::Reference< css::accessibility::XAccessibleRelationSet>& rxRelationSet)
+ throw (css::uno::RuntimeException);
//===== XAccessible =====================================================
/// Return the XAccessibleContext.
- virtual ::com::sun::star::uno::Reference<
- ::com::sun::star::accessibility::XAccessibleContext> SAL_CALL
- getAccessibleContext() throw (::com::sun::star::uno::RuntimeException, std::exception) override;
+ virtual css::uno::Reference< css::accessibility::XAccessibleContext> SAL_CALL
+ getAccessibleContext() throw (css::uno::RuntimeException, std::exception) override;
//===== XAccessibleContext ==============================================
/// Return the number of currently visible children.
virtual sal_Int32 SAL_CALL
- getAccessibleChildCount() throw (::com::sun::star::uno::RuntimeException, std::exception) override;
+ getAccessibleChildCount() throw (css::uno::RuntimeException, std::exception) override;
/// Return the specified child or throw exception.
- virtual ::com::sun::star::uno::Reference< ::com::sun::star::accessibility::XAccessible> SAL_CALL
+ virtual css::uno::Reference< css::accessibility::XAccessible> SAL_CALL
getAccessibleChild (sal_Int32 nIndex)
- throw (::com::sun::star::lang::IndexOutOfBoundsException, ::com::sun::star::uno::RuntimeException, std::exception) override;
+ throw (css::lang::IndexOutOfBoundsException, css::uno::RuntimeException, std::exception) override;
/// Return a reference to the parent.
- virtual ::com::sun::star::uno::Reference< ::com::sun::star::accessibility::XAccessible> SAL_CALL
+ virtual css::uno::Reference< css::accessibility::XAccessible> SAL_CALL
getAccessibleParent()
- throw (::com::sun::star::uno::RuntimeException, std::exception) override;
+ throw (css::uno::RuntimeException, std::exception) override;
/// Return this objects index among the parents children.
virtual sal_Int32 SAL_CALL
getAccessibleIndexInParent()
- throw (::com::sun::star::uno::RuntimeException, std::exception) override;
+ throw (css::uno::RuntimeException, std::exception) override;
/// Return this object's role.
virtual sal_Int16 SAL_CALL
getAccessibleRole()
- throw (::com::sun::star::uno::RuntimeException, std::exception) override;
+ throw (css::uno::RuntimeException, std::exception) override;
/// Return this object's description.
virtual OUString SAL_CALL
getAccessibleDescription()
- throw (::com::sun::star::uno::RuntimeException, std::exception) override;
+ throw (css::uno::RuntimeException, std::exception) override;
/// Return the object's current name.
virtual OUString SAL_CALL
getAccessibleName()
- throw (::com::sun::star::uno::RuntimeException, std::exception) override;
+ throw (css::uno::RuntimeException, std::exception) override;
/// Return NULL to indicate that an empty relation set.
- virtual ::com::sun::star::uno::Reference<
- ::com::sun::star::accessibility::XAccessibleRelationSet> SAL_CALL
+ virtual css::uno::Reference< css::accessibility::XAccessibleRelationSet> SAL_CALL
getAccessibleRelationSet()
- throw (::com::sun::star::uno::RuntimeException, std::exception) override;
+ throw (css::uno::RuntimeException, std::exception) override;
/// Return the set of current states.
- virtual ::com::sun::star::uno::Reference<
- ::com::sun::star::accessibility::XAccessibleStateSet> SAL_CALL
+ virtual css::uno::Reference< css::accessibility::XAccessibleStateSet> SAL_CALL
getAccessibleStateSet()
- throw (::com::sun::star::uno::RuntimeException, std::exception) override;
+ throw (css::uno::RuntimeException, std::exception) override;
/** Return the parents locale or throw exception if this object has no
parent yet/anymore.
*/
- virtual ::com::sun::star::lang::Locale SAL_CALL
+ virtual css::lang::Locale SAL_CALL
getLocale()
- throw (::com::sun::star::uno::RuntimeException,
- ::com::sun::star::accessibility::IllegalAccessibleComponentStateException, std::exception) override;
+ throw (css::uno::RuntimeException,
+ css::accessibility::IllegalAccessibleComponentStateException, std::exception) override;
//===== XAccessibleEventBroadcaster ========================================
virtual void SAL_CALL
addAccessibleEventListener (
- const ::com::sun::star::uno::Reference<
- ::com::sun::star::accessibility::XAccessibleEventListener >& xListener)
- throw (::com::sun::star::uno::RuntimeException, std::exception) override;
+ const css::uno::Reference< css::accessibility::XAccessibleEventListener >& xListener)
+ throw (css::uno::RuntimeException, std::exception) override;
virtual void SAL_CALL
removeAccessibleEventListener (
- const ::com::sun::star::uno::Reference<
- ::com::sun::star::accessibility::XAccessibleEventListener >& xListener)
- throw (::com::sun::star::uno::RuntimeException, std::exception) override;
+ const css::uno::Reference< css::accessibility::XAccessibleEventListener >& xListener)
+ throw (css::uno::RuntimeException, std::exception) override;
//===== XServiceInfo ====================================================
@@ -255,47 +248,45 @@ public:
*/
virtual OUString SAL_CALL
getImplementationName()
- throw (::com::sun::star::uno::RuntimeException, std::exception) override;
+ throw (css::uno::RuntimeException, std::exception) override;
/** Return whether the specified service is supported by this class.
*/
virtual sal_Bool SAL_CALL
supportsService (const OUString& sServiceName)
- throw (::com::sun::star::uno::RuntimeException, std::exception) override;
+ throw (css::uno::RuntimeException, std::exception) override;
/** Returns a list of all supported services. In this case that is just
the AccessibleContext service.
*/
- virtual ::com::sun::star::uno::Sequence< OUString> SAL_CALL
+ virtual css::uno::Sequence< OUString> SAL_CALL
getSupportedServiceNames()
- throw (::com::sun::star::uno::RuntimeException, std::exception) override;
+ throw (css::uno::RuntimeException, std::exception) override;
//===== XTypeProvider ===================================================
/** Returns a sequence of all supported interfaces.
*/
- virtual ::com::sun::star::uno::Sequence< ::com::sun::star::uno::Type> SAL_CALL
+ virtual css::uno::Sequence< css::uno::Type> SAL_CALL
getTypes()
- throw (::com::sun::star::uno::RuntimeException, std::exception) override;
+ throw (css::uno::RuntimeException, std::exception) override;
/** Returns a implementation id.
*/
- virtual ::com::sun::star::uno::Sequence<sal_Int8> SAL_CALL
+ virtual css::uno::Sequence<sal_Int8> SAL_CALL
getImplementationId()
- throw (::com::sun::star::uno::RuntimeException, std::exception) override;
+ throw (css::uno::RuntimeException, std::exception) override;
protected:
/** The state set.
*/
- ::com::sun::star::uno::Reference<
- ::com::sun::star::accessibility::XAccessibleStateSet> mxStateSet;
+ css::uno::Reference< css::accessibility::XAccessibleStateSet> mxStateSet;
/** The relation set. Relations can be set or removed by calling the
<member>AddRelation</member> and <member>RemoveRelation</member> methods.
*/
- ::com::sun::star::uno::Reference<
- ::com::sun::star::accessibility::XAccessibleRelationSet> mxRelationSet;
+ css::uno::Reference< css::accessibility::XAccessibleRelationSet> mxRelationSet;
// This method is called from the component helper base class while disposing.
virtual void SAL_CALL disposing() override;
@@ -307,7 +298,7 @@ protected:
siblings) name.
*/
virtual OUString CreateAccessibleName()
- throw (::com::sun::star::uno::RuntimeException, std::exception);
+ throw (css::uno::RuntimeException, std::exception);
/** Create the accessible object's descriptive string. May be called
more than once.
@@ -316,9 +307,9 @@ protected:
*/
virtual OUString
CreateAccessibleDescription()
- throw (::com::sun::star::uno::RuntimeException, std::exception);
+ throw (css::uno::RuntimeException, std::exception);
- void FireEvent (const ::com::sun::star::accessibility::AccessibleEventObject& aEvent);
+ void FireEvent (const css::accessibility::AccessibleEventObject& aEvent);
/** Check whether or not the object has been disposed (or is in the
state of being disposed). If that is the case then
@@ -326,7 +317,7 @@ protected:
foul deed.
*/
void ThrowIfDisposed()
- throw (::com::sun::star::lang::DisposedException);
+ throw (css::lang::DisposedException);
/** Check whether or not the object has been disposed (or is in the
state of being disposed).
@@ -346,8 +337,7 @@ protected:
private:
/// Reference to the parent object.
- ::com::sun::star::uno::Reference<
- ::com::sun::star::accessibility::XAccessible> mxParent;
+ css::uno::Reference< css::accessibility::XAccessible> mxParent;
/** Description of this object. This is not a constant because it can
be set from the outside. Furthermore, it changes according to the
diff --git a/include/editeng/AccessibleEditableTextPara.hxx b/include/editeng/AccessibleEditableTextPara.hxx
index a008419..006b693 100644
--- a/include/editeng/AccessibleEditableTextPara.hxx
+++ b/include/editeng/AccessibleEditableTextPara.hxx
@@ -46,15 +46,15 @@
namespace accessibility
{
- typedef ::cppu::WeakComponentImplHelper< ::com::sun::star::accessibility::XAccessible,
- ::com::sun::star::accessibility::XAccessibleContext,
- ::com::sun::star::accessibility::XAccessibleComponent,
- ::com::sun::star::accessibility::XAccessibleEditableText,
- ::com::sun::star::accessibility::XAccessibleEventBroadcaster,
- ::com::sun::star::accessibility::XAccessibleTextAttributes,
- ::com::sun::star::accessibility::XAccessibleHypertext,
- ::com::sun::star::accessibility::XAccessibleMultiLineText,
- ::com::sun::star::lang::XServiceInfo > AccessibleTextParaInterfaceBase;
+ typedef ::cppu::WeakComponentImplHelper< css::accessibility::XAccessible,
+ css::accessibility::XAccessibleContext,
+ css::accessibility::XAccessibleComponent,
+ css::accessibility::XAccessibleEditableText,
+ css::accessibility::XAccessibleEventBroadcaster,
+ css::accessibility::XAccessibleTextAttributes,
+ css::accessibility::XAccessibleHypertext,
+ css::accessibility::XAccessibleMultiLineText,
+ css::lang::XServiceInfo > AccessibleTextParaInterfaceBase;
/** This class implements the actual text paragraphs for the EditEngine/Outliner UAA
*/
@@ -64,10 +64,10 @@ namespace accessibility
protected:
// override OCommonAccessibleText methods
virtual OUString implGetText() override;
- virtual ::com::sun::star::lang::Locale implGetLocale() override;
- virtual void implGetSelection( sal_Int32& nStartIndex, sal_Int32& nEndIndex ) override;
- virtual void implGetParagraphBoundary( ::com::sun::star::i18n::Boundary& rBoundary, sal_Int32 nIndex ) override;
- virtual void implGetLineBoundary( ::com::sun::star::i18n::Boundary& rBoundary, sal_Int32 nIndex ) override;
+ virtual css::lang::Locale implGetLocale() override;
+ virtual void implGetSelection( sal_Int32& nStartIndex, sal_Int32& nEndIndex ) override;
+ virtual void implGetParagraphBoundary( css::i18n::Boundary& rBoundary, sal_Int32 nIndex ) override;
+ virtual void implGetLineBoundary( css::i18n::Boundary& rBoundary, sal_Int32 nIndex ) override;
public:
/// Create accessible object for given parent
@@ -75,99 +75,99 @@ namespace accessibility
// - add parameter <_pParaManager> (default value NULL)
// This has to be the instance of <AccessibleParaManager>, which
// created and manages this accessible paragraph.
- AccessibleEditableTextPara ( const ::com::sun::star::uno::Reference< ::com::sun::star::accessibility::XAccessible >& rParent,
+ AccessibleEditableTextPara ( const css::uno::Reference< css::accessibility::XAccessible >& rParent,
const AccessibleParaManager* _pParaManager = NULL );
virtual ~AccessibleEditableTextPara ();
// XInterface
- virtual ::com::sun::star::uno::Any SAL_CALL queryInterface (const ::com::sun::star::uno::Type & rType) throw (::com::sun::star::uno::RuntimeException, std::exception) override;
+ virtual css::uno::Any SAL_CALL queryInterface (const css::uno::Type & rType) throw (css::uno::RuntimeException, std::exception) override;
// XAccessible
- virtual ::com::sun::star::uno::Reference< ::com::sun::star::accessibility::XAccessibleContext > SAL_CALL getAccessibleContext( ) throw (::com::sun::star::uno::RuntimeException, std::exception) override;
+ virtual css::uno::Reference< css::accessibility::XAccessibleContext > SAL_CALL getAccessibleContext( ) throw (css::uno::RuntimeException, std::exception) override;
// XAccessibleContext
- virtual sal_Int32 SAL_CALL getAccessibleChildCount() throw (::com::sun::star::uno::RuntimeException, std::exception) override;
- virtual ::com::sun::star::uno::Reference< ::com::sun::star::accessibility::XAccessible > SAL_CALL getAccessibleChild( sal_Int32 i ) throw (::com::sun::star::lang::IndexOutOfBoundsException, ::com::sun::star::uno::RuntimeException, std::exception) override;
- virtual ::com::sun::star::uno::Reference< ::com::sun::star::accessibility::XAccessible > SAL_CALL getAccessibleParent() throw (::com::sun::star::uno::RuntimeException, std::exception) override;
- virtual sal_Int32 SAL_CALL getAccessibleIndexInParent() throw (::com::sun::star::uno::RuntimeException, std::exception) override;
- virtual sal_Int16 SAL_CALL getAccessibleRole() throw (::com::sun::star::uno::RuntimeException, std::exception) override;
+ virtual sal_Int32 SAL_CALL getAccessibleChildCount() throw (css::uno::RuntimeException, std::exception) override;
+ virtual css::uno::Reference< css::accessibility::XAccessible > SAL_CALL getAccessibleChild( sal_Int32 i ) throw (css::lang::IndexOutOfBoundsException, css::uno::RuntimeException, std::exception) override;
+ virtual css::uno::Reference< css::accessibility::XAccessible > SAL_CALL getAccessibleParent() throw (css::uno::RuntimeException, std::exception) override;
+ virtual sal_Int32 SAL_CALL getAccessibleIndexInParent() throw (css::uno::RuntimeException, std::exception) override;
+ virtual sal_Int16 SAL_CALL getAccessibleRole() throw (css::uno::RuntimeException, std::exception) override;
/// Maximal length of text returned by getAccessibleDescription()
enum { MaxDescriptionLen = 40 };
- virtual OUString SAL_CALL getAccessibleDescription() throw (::com::sun::star::uno::RuntimeException, std::exception) override;
- virtual OUString SAL_CALL getAccessibleName() throw (::com::sun::star::uno::RuntimeException, std::exception) override;
- virtual ::com::sun::star::uno::Reference< ::com::sun::star::accessibility::XAccessibleRelationSet > SAL_CALL getAccessibleRelationSet() throw (::com::sun::star::uno::RuntimeException, std::exception) override;
- virtual ::com::sun::star::uno::Reference< ::com::sun::star::accessibility::XAccessibleStateSet > SAL_CALL getAccessibleStateSet() throw (::com::sun::star::uno::RuntimeException, std::exception) override;
- virtual ::com::sun::star::lang::Locale SAL_CALL getLocale() throw (::com::sun::star::accessibility::IllegalAccessibleComponentStateException, ::com::sun::star::uno::RuntimeException, std::exception) override;
+ virtual OUString SAL_CALL getAccessibleDescription() throw (css::uno::RuntimeException, std::exception) override;
+ virtual OUString SAL_CALL getAccessibleName() throw (css::uno::RuntimeException, std::exception) override;
+ virtual css::uno::Reference< css::accessibility::XAccessibleRelationSet > SAL_CALL getAccessibleRelationSet() throw (css::uno::RuntimeException, std::exception) override;
+ virtual css::uno::Reference< css::accessibility::XAccessibleStateSet > SAL_CALL getAccessibleStateSet() throw (css::uno::RuntimeException, std::exception) override;
+ virtual css::lang::Locale SAL_CALL getLocale() throw (css::accessibility::IllegalAccessibleComponentStateException, css::uno::RuntimeException, std::exception) override;
// XAccessibleEventBroadcaster
- virtual void SAL_CALL addAccessibleEventListener( const ::com::sun::star::uno::Reference< ::com::sun::star::accessibility::XAccessibleEventListener >& xListener ) throw (::com::sun::star::uno::RuntimeException, std::exception) override;
- virtual void SAL_CALL removeAccessibleEventListener( const ::com::sun::star::uno::Reference< ::com::sun::star::accessibility::XAccessibleEventListener >& xListener ) throw (::com::sun::star::uno::RuntimeException, std::exception) override;
+ virtual void SAL_CALL addAccessibleEventListener( const css::uno::Reference< css::accessibility::XAccessibleEventListener >& xListener ) throw (css::uno::RuntimeException, std::exception) override;
+ virtual void SAL_CALL removeAccessibleEventListener( const css::uno::Reference< css::accessibility::XAccessibleEventListener >& xListener ) throw (css::uno::RuntimeException, std::exception) override;
// XAccessibleComponent
- virtual sal_Bool SAL_CALL containsPoint( const ::com::sun::star::awt::Point& aPoint ) throw (::com::sun::star::uno::RuntimeException, std::exception) override;
- virtual ::com::sun::star::uno::Reference< ::com::sun::star::accessibility::XAccessible > SAL_CALL getAccessibleAtPoint( const ::com::sun::star::awt::Point& aPoint ) throw (::com::sun::star::uno::RuntimeException, std::exception) override;
- virtual ::com::sun::star::awt::Rectangle SAL_CALL getBounds( ) throw (::com::sun::star::uno::RuntimeException, std::exception) override;
- virtual ::com::sun::star::awt::Point SAL_CALL getLocation( ) throw (::com::sun::star::uno::RuntimeException, std::exception) override;
- virtual ::com::sun::star::awt::Point SAL_CALL getLocationOnScreen( ) throw (::com::sun::star::uno::RuntimeException, std::exception) override;
- virtual ::com::sun::star::awt::Size SAL_CALL getSize( ) throw (::com::sun::star::uno::RuntimeException, std::exception) override;
- virtual void SAL_CALL grabFocus( ) throw (::com::sun::star::uno::RuntimeException, std::exception) override;
- virtual sal_Int32 SAL_CALL getForeground( ) throw (::com::sun::star::uno::RuntimeException, std::exception) override;
- virtual sal_Int32 SAL_CALL getBackground( ) throw (::com::sun::star::uno::RuntimeException, std::exception) override;
+ virtual sal_Bool SAL_CALL containsPoint( const css::awt::Point& aPoint ) throw (css::uno::RuntimeException, std::exception) override;
+ virtual css::uno::Reference< css::accessibility::XAccessible > SAL_CALL getAccessibleAtPoint( const css::awt::Point& aPoint ) throw (css::uno::RuntimeException, std::exception) override;
+ virtual css::awt::Rectangle SAL_CALL getBounds( ) throw (css::uno::RuntimeException, std::exception) override;
+ virtual css::awt::Point SAL_CALL getLocation( ) throw (css::uno::RuntimeException, std::exception) override;
+ virtual css::awt::Point SAL_CALL getLocationOnScreen( ) throw (css::uno::RuntimeException, std::exception) override;
+ virtual css::awt::Size SAL_CALL getSize( ) throw (css::uno::RuntimeException, std::exception) override;
+ virtual void SAL_CALL grabFocus( ) throw (css::uno::RuntimeException, std::exception) override;
+ virtual sal_Int32 SAL_CALL getForeground( ) throw (css::uno::RuntimeException, std::exception) override;
+ virtual sal_Int32 SAL_CALL getBackground( ) throw (css::uno::RuntimeException, std::exception) override;
// XAccessibleText (this comes implicitly inherited by XAccessibleEditableText AND by XAccessibleMultiLineText)
- virtual sal_Int32 SAL_CALL getCaretPosition() throw (::com::sun::star::uno::RuntimeException, std::exception) override;
- virtual sal_Bool SAL_CALL setCaretPosition( sal_Int32 nIndex ) throw (::com::sun::star::lang::IndexOutOfBoundsException, ::com::sun::star::uno::RuntimeException, std::exception) override;
- virtual sal_Unicode SAL_CALL getCharacter( sal_Int32 nIndex ) throw (::com::sun::star::lang::IndexOutOfBoundsException, ::com::sun::star::uno::RuntimeException, std::exception) override;
- virtual ::com::sun::star::uno::Sequence< ::com::sun::star::beans::PropertyValue > SAL_CALL getCharacterAttributes( sal_Int32 nIndex, const ::com::sun::star::uno::Sequence< OUString >& aRequestedAttributes ) throw (::com::sun::star::lang::IndexOutOfBoundsException, ::com::sun::star::beans::UnknownPropertyException, ::com::sun::star::uno::RuntimeException, std::exception) override;
- virtual ::com::sun::star::awt::Rectangle SAL_CALL getCharacterBounds( sal_Int32 nIndex ) throw (::com::sun::star::lang::IndexOutOfBoundsException, ::com::sun::star::uno::RuntimeException, std::exception) override;
- virtual sal_Int32 SAL_CALL getCharacterCount() throw (::com::sun::star::uno::RuntimeException, std::exception) override;
- virtual sal_Int32 SAL_CALL getIndexAtPoint( const ::com::sun::star::awt::Point& aPoint ) throw (::com::sun::star::uno::RuntimeException, std::exception) override;
- virtual OUString SAL_CALL getSelectedText() throw (::com::sun::star::uno::RuntimeException, std::exception) override;
- virtual sal_Int32 SAL_CALL getSelectionStart() throw (::com::sun::star::uno::RuntimeException, std::exception) override;
- virtual sal_Int32 SAL_CALL getSelectionEnd() throw (::com::sun::star::uno::RuntimeException, std::exception) override;
- virtual sal_Bool SAL_CALL setSelection( sal_Int32 nStartIndex, sal_Int32 nEndIndex ) throw (::com::sun::star::lang::IndexOutOfBoundsException, ::com::sun::star::uno::RuntimeException, std::exception) override;
- virtual OUString SAL_CALL getText() throw (::com::sun::star::uno::RuntimeException, std::exception) override;
- virtual OUString SAL_CALL getTextRange( sal_Int32 nStartIndex, sal_Int32 nEndIndex ) throw (::com::sun::star::lang::IndexOutOfBoundsException, ::com::sun::star::uno::RuntimeException, std::exception) override;
+ virtual sal_Int32 SAL_CALL getCaretPosition() throw (css::uno::RuntimeException, std::exception) override;
+ virtual sal_Bool SAL_CALL setCaretPosition( sal_Int32 nIndex ) throw (css::lang::IndexOutOfBoundsException, css::uno::RuntimeException, std::exception) override;
+ virtual sal_Unicode SAL_CALL getCharacter( sal_Int32 nIndex ) throw (css::lang::IndexOutOfBoundsException, css::uno::RuntimeException, std::exception) override;
+ virtual css::uno::Sequence< css::beans::PropertyValue > SAL_CALL getCharacterAttributes( sal_Int32 nIndex, const css::uno::Sequence< OUString >& aRequestedAttributes ) throw (css::lang::IndexOutOfBoundsException, css::beans::UnknownPropertyException, css::uno::RuntimeException, std::exception) override;
+ virtual css::awt::Rectangle SAL_CALL getCharacterBounds( sal_Int32 nIndex ) throw (css::lang::IndexOutOfBoundsException, css::uno::RuntimeException, std::exception) override;
+ virtual sal_Int32 SAL_CALL getCharacterCount() throw (css::uno::RuntimeException, std::exception) override;
+ virtual sal_Int32 SAL_CALL getIndexAtPoint( const css::awt::Point& aPoint ) throw (css::uno::RuntimeException, std::exception) override;
+ virtual OUString SAL_CALL getSelectedText() throw (css::uno::RuntimeException, std::exception) override;
+ virtual sal_Int32 SAL_CALL getSelectionStart() throw (css::uno::RuntimeException, std::exception) override;
+ virtual sal_Int32 SAL_CALL getSelectionEnd() throw (css::uno::RuntimeException, std::exception) override;
+ virtual sal_Bool SAL_CALL setSelection( sal_Int32 nStartIndex, sal_Int32 nEndIndex ) throw (css::lang::IndexOutOfBoundsException, css::uno::RuntimeException, std::exception) override;
+ virtual OUString SAL_CALL getText() throw (css::uno::RuntimeException, std::exception) override;
+ virtual OUString SAL_CALL getTextRange( sal_Int32 nStartIndex, sal_Int32 nEndIndex ) throw (css::lang::IndexOutOfBoundsException, css::uno::RuntimeException, std::exception) override;
/// Does not support AccessibleTextType::SENTENCE (missing feature in EditEngine)
- virtual ::com::sun::star::accessibility::TextSegment SAL_CALL getTextAtIndex( sal_Int32 nIndex, sal_Int16 aTextType ) throw (::com::sun::star::lang::IndexOutOfBoundsException, ::com::sun::star::lang::IllegalArgumentException, ::com::sun::star::uno::RuntimeException, std::exception) override;
+ virtual css::accessibility::TextSegment SAL_CALL getTextAtIndex( sal_Int32 nIndex, sal_Int16 aTextType ) throw (css::lang::IndexOutOfBoundsException, css::lang::IllegalArgumentException, css::uno::RuntimeException, std::exception) override;
/// Does not support AccessibleTextType::SENTENCE (missing feature in EditEngine)
- virtual ::com::sun::star::accessibility::TextSegment SAL_CALL getTextBeforeIndex( sal_Int32 nIndex, sal_Int16 aTextType ) throw (::com::sun::star::lang::IndexOutOfBoundsException, ::com::sun::star::lang::IllegalArgumentException, ::com::sun::star::uno::RuntimeException, std::exception) override;
+ virtual css::accessibility::TextSegment SAL_CALL getTextBeforeIndex( sal_Int32 nIndex, sal_Int16 aTextType ) throw (css::lang::IndexOutOfBoundsException, css::lang::IllegalArgumentException, css::uno::RuntimeException, std::exception) override;
/// Does not support AccessibleTextType::SENTENCE (missing feature in EditEngine)
- virtual ::com::sun::star::accessibility::TextSegment SAL_CALL getTextBehindIndex( sal_Int32 nIndex, sal_Int16 aTextType ) throw (::com::sun::star::lang::IndexOutOfBoundsException, ::com::sun::star::lang::IllegalArgumentException, ::com::sun::star::uno::RuntimeException, std::exception) override;
- virtual sal_Bool SAL_CALL copyText( sal_Int32 nStartIndex, sal_Int32 nEndIndex ) throw (::com::sun::star::lang::IndexOutOfBoundsException, ::com::sun::star::uno::RuntimeException, std::exception) override;
+ virtual css::accessibility::TextSegment SAL_CALL getTextBehindIndex( sal_Int32 nIndex, sal_Int16 aTextType ) throw (css::lang::IndexOutOfBoundsException, css::lang::IllegalArgumentException, css::uno::RuntimeException, std::exception) override;
+ virtual sal_Bool SAL_CALL copyText( sal_Int32 nStartIndex, sal_Int32 nEndIndex ) throw (css::lang::IndexOutOfBoundsException, css::uno::RuntimeException, std::exception) override;
// XAccessibleEditableText
- virtual sal_Bool SAL_CALL cutText( sal_Int32 nStartIndex, sal_Int32 nEndIndex ) throw (::com::sun::star::lang::IndexOutOfBoundsException, ::com::sun::star::uno::RuntimeException, std::exception) override;
- virtual sal_Bool SAL_CALL pasteText( sal_Int32 nIndex ) throw (::com::sun::star::lang::IndexOutOfBoundsException, ::com::sun::star::uno::RuntimeException, std::exception) override;
- virtual sal_Bool SAL_CALL deleteText( sal_Int32 nStartIndex, sal_Int32 nEndIndex ) throw (::com::sun::star::lang::IndexOutOfBoundsException, ::com::sun::star::uno::RuntimeException, std::exception) override;
- virtual sal_Bool SAL_CALL insertText( const OUString& sText, sal_Int32 nIndex ) throw (::com::sun::star::lang::IndexOutOfBoundsException, ::com::sun::star::uno::RuntimeException, std::exception) override;
- virtual sal_Bool SAL_CALL replaceText( sal_Int32 nStartIndex, sal_Int32 nEndIndex, const OUString& sReplacement ) throw (::com::sun::star::lang::IndexOutOfBoundsException, ::com::sun::star::uno::RuntimeException, std::exception) override;
- virtual sal_Bool SAL_CALL setAttributes( sal_Int32 nStartIndex, sal_Int32 nEndIndex, const ::com::sun::star::uno::Sequence< ::com::sun::star::beans::PropertyValue >& aAttributeSet ) throw (::com::sun::star::lang::IndexOutOfBoundsException, ::com::sun::star::uno::RuntimeException, std::exception) override;
- virtual sal_Bool SAL_CALL setText( const OUString& sText ) throw (::com::sun::star::uno::RuntimeException, std::exception) override;
+ virtual sal_Bool SAL_CALL cutText( sal_Int32 nStartIndex, sal_Int32 nEndIndex ) throw (css::lang::IndexOutOfBoundsException, css::uno::RuntimeException, std::exception) override;
+ virtual sal_Bool SAL_CALL pasteText( sal_Int32 nIndex ) throw (css::lang::IndexOutOfBoundsException, css::uno::RuntimeException, std::exception) override;
+ virtual sal_Bool SAL_CALL deleteText( sal_Int32 nStartIndex, sal_Int32 nEndIndex ) throw (css::lang::IndexOutOfBoundsException, css::uno::RuntimeException, std::exception) override;
+ virtual sal_Bool SAL_CALL insertText( const OUString& sText, sal_Int32 nIndex ) throw (css::lang::IndexOutOfBoundsException, css::uno::RuntimeException, std::exception) override;
+ virtual sal_Bool SAL_CALL replaceText( sal_Int32 nStartIndex, sal_Int32 nEndIndex, const OUString& sReplacement ) throw (css::lang::IndexOutOfBoundsException, css::uno::RuntimeException, std::exception) override;
+ virtual sal_Bool SAL_CALL setAttributes( sal_Int32 nStartIndex, sal_Int32 nEndIndex, const css::uno::Sequence< css::beans::PropertyValue >& aAttributeSet ) throw (css::lang::IndexOutOfBoundsException, css::uno::RuntimeException, std::exception) override;
+ virtual sal_Bool SAL_CALL setText( const OUString& sText ) throw (css::uno::RuntimeException, std::exception) override;
// XAccessibleTextAttributes
- virtual ::com::sun::star::uno::Sequence< ::com::sun::star::beans::PropertyValue > SAL_CALL getDefaultAttributes( const ::com::sun::star::uno::Sequence< OUString >& RequestedAttributes ) throw (::com::sun::star::beans::UnknownPropertyException, ::com::sun::star::uno::RuntimeException, std::exception) override;
- virtual ::com::sun::star::uno::Sequence< ::com::sun::star::beans::PropertyValue > SAL_CALL getRunAttributes( ::sal_Int32 Index, const ::com::sun::star::uno::Sequence< OUString >& RequestedAttributes ) throw (css::beans::UnknownPropertyException, css::lang::IndexOutOfBoundsException, css::uno::RuntimeException, std::exception) override;
+ virtual css::uno::Sequence< css::beans::PropertyValue > SAL_CALL getDefaultAttributes( const css::uno::Sequence< OUString >& RequestedAttributes ) throw (css::beans::UnknownPropertyException, css::uno::RuntimeException, std::exception) override;
+ virtual css::uno::Sequence< css::beans::PropertyValue > SAL_CALL getRunAttributes( ::sal_Int32 Index, const css::uno::Sequence< OUString >& RequestedAttributes ) throw (css::beans::UnknownPropertyException, css::lang::IndexOutOfBoundsException, css::uno::RuntimeException, std::exception) override;
// XAccessibleHypertext
- virtual ::sal_Int32 SAL_CALL getHyperLinkCount( ) throw (::com::sun::star::uno::RuntimeException, std::exception) override;
- virtual ::com::sun::star::uno::Reference< ::com::sun::star::accessibility::XAccessibleHyperlink > SAL_CALL getHyperLink( ::sal_Int32 nLinkIndex ) throw (::com::sun::star::lang::IndexOutOfBoundsException, ::com::sun::star::uno::RuntimeException, std::exception) override;
- virtual ::sal_Int32 SAL_CALL getHyperLinkIndex( ::sal_Int32 nCharIndex ) throw (::com::sun::star::lang::IndexOutOfBoundsException, ::com::sun::star::uno::RuntimeException, std::exception) override;
+ virtual ::sal_Int32 SAL_CALL getHyperLinkCount( ) throw (css::uno::RuntimeException, std::exception) override;
+ virtual css::uno::Reference< css::accessibility::XAccessibleHyperlink > SAL_CALL getHyperLink( ::sal_Int32 nLinkIndex ) throw (css::lang::IndexOutOfBoundsException, css::uno::RuntimeException, std::exception) override;
+ virtual ::sal_Int32 SAL_CALL getHyperLinkIndex( ::sal_Int32 nCharIndex ) throw (css::lang::IndexOutOfBoundsException, css::uno::RuntimeException, std::exception) override;
// XAccessibleMultiLineText
- virtual ::sal_Int32 SAL_CALL getLineNumberAtIndex( ::sal_Int32 nIndex ) throw (::com::sun::star::lang::IndexOutOfBoundsException, ::com::sun::star::uno::RuntimeException, std::exception) override;
- virtual ::com::sun::star::accessibility::TextSegment SAL_CALL getTextAtLineNumber( ::sal_Int32 nLineNo ) throw (::com::sun::star::lang::IndexOutOfBoundsException, ::com::sun::star::uno::RuntimeException, std::exception) override;
- virtual ::com::sun::star::accessibility::TextSegment SAL_CALL getTextAtLineWithCaret( ) throw (::com::sun::star::uno::RuntimeException, std::exception) override;
- virtual ::sal_Int32 SAL_CALL getNumberOfLineWithCaret( ) throw (::com::sun::star::uno::RuntimeException, std::exception) override;
+ virtual ::sal_Int32 SAL_CALL getLineNumberAtIndex( ::sal_Int32 nIndex ) throw (css::lang::IndexOutOfBoundsException, css::uno::RuntimeException, std::exception) override;
+ virtual css::accessibility::TextSegment SAL_CALL getTextAtLineNumber( ::sal_Int32 nLineNo ) throw (css::lang::IndexOutOfBoundsException, css::uno::RuntimeException, std::exception) override;
+ virtual css::accessibility::TextSegment SAL_CALL getTextAtLineWithCaret( ) throw (css::uno::RuntimeException, std::exception) override;
+ virtual ::sal_Int32 SAL_CALL getNumberOfLineWithCaret( ) throw (css::uno::RuntimeException, std::exception) override;
// XServiceInfo
- virtual OUString SAL_CALL getImplementationName() throw (::com::sun::star::uno::RuntimeException, std::exception) override;
- virtual sal_Bool SAL_CALL supportsService (const OUString& sServiceName) throw (::com::sun::star::uno::RuntimeException, std::exception) override;
- virtual ::com::sun::star::uno::Sequence< OUString> SAL_CALL getSupportedServiceNames() throw (::com::sun::star::uno::RuntimeException, std::exception) override;
+ virtual OUString SAL_CALL getImplementationName() throw (css::uno::RuntimeException, std::exception) override;
+ virtual sal_Bool SAL_CALL supportsService (const OUString& sServiceName) throw (css::uno::RuntimeException, std::exception) override;
+ virtual css::uno::Sequence< OUString> SAL_CALL getSupportedServiceNames() throw (css::uno::RuntimeException, std::exception) override;
// XServiceName
- static OUString SAL_CALL getServiceName() throw (::com::sun::star::uno::RuntimeException);
+ static OUString SAL_CALL getServiceName() throw (css::uno::RuntimeException);
/** Set the current index in the accessibility parent
@@ -230,7 +230,7 @@ namespace accessibility
void Dispose();
/// Calls all Listener objects to tell them the change. Don't hold locks when calling this!
- void FireEvent(const sal_Int16 nEventId, const ::com::sun::star::uno::Any& rNewValue = ::com::sun::star::uno::Any(), const ::com::sun::star::uno::Any& rOldValue = ::com::sun::star::uno::Any() ) const;
+ void FireEvent(const sal_Int16 nEventId, const css::uno::Any& rNewValue = css::uno::Any(), const css::uno::Any& rOldValue = css::uno::Any() ) const;
/// Sets the given state on the internal state set and fires STATE_CHANGE event. Don't hold locks when calling this!
void SetState( const sal_Int16 nStateId );
@@ -305,8 +305,8 @@ namespace accessibility
bool GetAttributeRun( sal_Int32& nStartIndex, sal_Int32& nEndIndex, sal_Int32 nIndex );
// syntactic sugar for FireEvent
- void GotPropertyEvent( const ::com::sun::star::uno::Any& rNewValue, const sal_Int16 nEventId ) const;
- void LostPropertyEvent( const ::com::sun::star::uno::Any& rOldValue, const sal_Int16 nEventId ) const;
+ void GotPropertyEvent( const css::uno::Any& rNewValue, const sal_Int16 nEventId ) const;
+ void LostPropertyEvent( const css::uno::Any& rOldValue, const sal_Int16 nEventId ) const;
int getNotifierClientId() const { return mnNotifierClientId; }
@@ -341,10 +341,10 @@ namespace accessibility
/// Check whether 0<=nStart<=n and 0<=nEnd<=n
void CheckRange( sal_Int32 nStart, sal_Int32 nEnd );
- void _correctValues( const sal_Int32 nIndex, ::com::sun::star::uno::Sequence< ::com::sun::star::beans::PropertyValue >& rValues );
+ void _correctValues( const sal_Int32 nIndex, css::uno::Sequence< css::beans::PropertyValue >& rValues );
sal_Int32 SkipField(sal_Int32 nIndex, bool bForward);
// get overlapped field, extend return string. Only extend forward for now
- bool ExtendByField( ::com::sun::star::accessibility::TextSegment& Segment );
+ bool ExtendByField( css::accessibility::TextSegment& Segment );
OUString GetFieldTypeNameAtIndex(sal_Int32 nIndex);
// the paragraph index in the edit engine (guarded by solar mutex)
sal_Int32 mnParagraphIndex;
@@ -356,7 +356,7 @@ namespace accessibility
SvxEditSourceAdapter* mpEditSource;
// the possible child (for image bullets, guarded by solar mutex)
- typedef WeakCppRef < ::com::sun::star::accessibility::XAccessible, AccessibleImageBullet > WeakBullet;
+ typedef WeakCppRef < css::accessibility::XAccessible, AccessibleImageBullet > WeakBullet;
WeakBullet maImageBullet;
// the last string used for an Accessibility::TEXT_CHANGED event (guarded by solar mutex)
@@ -366,15 +366,15 @@ namespace accessibility
Point maEEOffset;
// the current state set (updated from SetState/UnSetState and guarded by solar mutex)
- ::com::sun::star::uno::Reference< ::com::sun::star::accessibility::XAccessibleStateSet > mxStateSet;
+ css::uno::Reference< css::accessibility::XAccessibleStateSet > mxStateSet;
/// The shape we're the accessible for (unguarded)
- ::com::sun::star::uno::Reference< ::com::sun::star::accessibility::XAccessible > mxParent;
+ css::uno::Reference< css::accessibility::XAccessible > mxParent;
/// Our listeners (guarded by maMutex)
int mnNotifierClientId;
private:
- ::com::sun::star::uno::Reference< ::com::sun::star::accessibility::XAccessible > m_xAccInfo;
+ css::uno::Reference< css::accessibility::XAccessible > m_xAccInfo;
// Text paragraphs should provide FLOWS_TO and FLOWS_FROM relations (#i27138#)
// the paragraph manager, which created this instance - is NULL, if
diff --git a/include/editeng/AccessibleImageBullet.hxx b/include/editeng/AccessibleImageBullet.hxx
index 1e0a0ba..f13908f 100644
--- a/include/editeng/AccessibleImageBullet.hxx
+++ b/include/editeng/AccessibleImageBullet.hxx
@@ -36,11 +36,11 @@
namespace accessibility
{
- typedef ::cppu::WeakImplHelper< ::com::sun::star::accessibility::XAccessible,
- ::com::sun::star::accessibility::XAccessibleContext,
- ::com::sun::star::accessibility::XAccessibleComponent,
- ::com::sun::star::accessibility::XAccessibleEventBroadcaster,
- ::com::sun::star::lang::XServiceInfo > AccessibleImageBulletInterfaceBase;
+ typedef ::cppu::WeakImplHelper< css::accessibility::XAccessible,
+ css::accessibility::XAccessibleContext,
+ css::accessibility::XAccessibleComponent,
+ css::accessibility::XAccessibleEventBroadcaster,
+ css::lang::XServiceInfo > AccessibleImageBulletInterfaceBase;
/** This class implements the image bullets for the EditEngine/Outliner UAA
*/
@@ -49,49 +49,49 @@ namespace accessibility
public:
/// Create accessible object for given parent
- AccessibleImageBullet ( const ::com::sun::star::uno::Reference< ::com::sun::star::accessibility::XAccessible >& rParent );
+ AccessibleImageBullet ( const css::uno::Reference< css::accessibility::XAccessible >& rParent );
virtual ~AccessibleImageBullet ();
// XInterface
- virtual ::com::sun::star::uno::Any SAL_CALL queryInterface (const ::com::sun::star::uno::Type & rType) throw (::com::sun::star::uno::RuntimeException, std::exception) override;
+ virtual css::uno::Any SAL_CALL queryInterface (const css::uno::Type & rType) throw (css::uno::RuntimeException, std::exception) override;
// XAccessible
- virtual ::com::sun::star::uno::Reference< ::com::sun::star::accessibility::XAccessibleContext > SAL_CALL getAccessibleContext( ) throw (::com::sun::star::uno::RuntimeException, std::exception) override;
+ virtual css::uno::Reference< css::accessibility::XAccessibleContext > SAL_CALL getAccessibleContext( ) throw (css::uno::RuntimeException, std::exception) override;
// XAccessibleContext
- virtual sal_Int32 SAL_CALL getAccessibleChildCount() throw (::com::sun::star::uno::RuntimeException, std::exception) override;
- virtual ::com::sun::star::uno::Reference< ::com::sun::star::accessibility::XAccessible > SAL_CALL getAccessibleChild( sal_Int32 i ) throw (::com::sun::star::lang::IndexOutOfBoundsException, ::com::sun::star::uno::RuntimeException, std::exception) override;
- virtual ::com::sun::star::uno::Reference< ::com::sun::star::accessibility::XAccessible > SAL_CALL getAccessibleParent() throw (::com::sun::star::uno::RuntimeException, std::exception) override;
- virtual sal_Int32 SAL_CALL getAccessibleIndexInParent() throw (::com::sun::star::uno::RuntimeException, std::exception) override;
- virtual sal_Int16 SAL_CALL getAccessibleRole() throw (::com::sun::star::uno::RuntimeException, std::exception) override;
+ virtual sal_Int32 SAL_CALL getAccessibleChildCount() throw (css::uno::RuntimeException, std::exception) override;
+ virtual css::uno::Reference< css::accessibility::XAccessible > SAL_CALL getAccessibleChild( sal_Int32 i ) throw (css::lang::IndexOutOfBoundsException, css::uno::RuntimeException, std::exception) override;
+ virtual css::uno::Reference< css::accessibility::XAccessible > SAL_CALL getAccessibleParent() throw (css::uno::RuntimeException, std::exception) override;
+ virtual sal_Int32 SAL_CALL getAccessibleIndexInParent() throw (css::uno::RuntimeException, std::exception) override;
+ virtual sal_Int16 SAL_CALL getAccessibleRole() throw (css::uno::RuntimeException, std::exception) override;
/// Maximal length of text returned by getAccessibleDescription()
enum { MaxDescriptionLen = 40 };
- virtual OUString SAL_CALL getAccessibleDescription() throw (::com::sun::star::uno::RuntimeException, std::exception) override;
- virtual OUString SAL_CALL getAccessibleName() throw (::com::sun::star::uno::RuntimeException, std::exception) override;
- virtual ::com::sun::star::uno::Reference< ::com::sun::star::accessibility::XAccessibleRelationSet > SAL_CALL getAccessibleRelationSet() throw (::com::sun::star::uno::RuntimeException, std::exception) override;
- virtual ::com::sun::star::uno::Reference< ::com::sun::star::accessibility::XAccessibleStateSet > SAL_CALL getAccessibleStateSet() throw (::com::sun::star::uno::RuntimeException, std::exception) override;
- virtual ::com::sun::star::lang::Locale SAL_CALL getLocale() throw (::com::sun::star::accessibility::IllegalAccessibleComponentStateException, ::com::sun::star::uno::RuntimeException, std::exception) override;
+ virtual OUString SAL_CALL getAccessibleDescription() throw (css::uno::RuntimeException, std::exception) override;
+ virtual OUString SAL_CALL getAccessibleName() throw (css::uno::RuntimeException, std::exception) override;
+ virtual css::uno::Reference< css::accessibility::XAccessibleRelationSet > SAL_CALL getAccessibleRelationSet() throw (css::uno::RuntimeException, std::exception) override;
+ virtual css::uno::Reference< css::accessibility::XAccessibleStateSet > SAL_CALL getAccessibleStateSet() throw (css::uno::RuntimeException, std::exception) override;
+ virtual css::lang::Locale SAL_CALL getLocale() throw (css::accessibility::IllegalAccessibleComponentStateException, css::uno::RuntimeException, std::exception) override;
// XAccessibleEventBroadcaster
- virtual void SAL_CALL addAccessibleEventListener( const ::com::sun::star::uno::Reference< ::com::sun::star::accessibility::XAccessibleEventListener >& xListener ) throw (::com::sun::star::uno::RuntimeException, std::exception) override;
- virtual void SAL_CALL removeAccessibleEventListener( const ::com::sun::star::uno::Reference< ::com::sun::star::accessibility::XAccessibleEventListener >& xListener ) throw (::com::sun::star::uno::RuntimeException, std::exception) override;
+ virtual void SAL_CALL addAccessibleEventListener( const css::uno::Reference< css::accessibility::XAccessibleEventListener >& xListener ) throw (css::uno::RuntimeException, std::exception) override;
+ virtual void SAL_CALL removeAccessibleEventListener( const css::uno::Reference< css::accessibility::XAccessibleEventListener >& xListener ) throw (css::uno::RuntimeException, std::exception) override;
// XAccessibleComponent
- virtual sal_Bool SAL_CALL containsPoint( const ::com::sun::star::awt::Point& aPoint ) throw (::com::sun::star::uno::RuntimeException, std::exception) override;
- virtual ::com::sun::star::uno::Reference< ::com::sun::star::accessibility::XAccessible > SAL_CALL getAccessibleAtPoint( const ::com::sun::star::awt::Point& aPoint ) throw (::com::sun::star::uno::RuntimeException, std::exception) override;
- virtual ::com::sun::star::awt::Rectangle SAL_CALL getBounds( ) throw (::com::sun::star::uno::RuntimeException, std::exception) override;
- virtual ::com::sun::star::awt::Point SAL_CALL getLocation( ) throw (::com::sun::star::uno::RuntimeException, std::exception) override;
- virtual ::com::sun::star::awt::Point SAL_CALL getLocationOnScreen( ) throw (::com::sun::star::uno::RuntimeException, std::exception) override;
- virtual ::com::sun::star::awt::Size SAL_CALL getSize( ) throw (::com::sun::star::uno::RuntimeException, std::exception) override;
- virtual void SAL_CALL grabFocus( ) throw (::com::sun::star::uno::RuntimeException, std::exception) override;
- virtual sal_Int32 SAL_CALL getForeground( ) throw (::com::sun::star::uno::RuntimeException, std::exception) override;
- virtual sal_Int32 SAL_CALL getBackground( ) throw (::com::sun::star::uno::RuntimeException, std::exception) override;
+ virtual sal_Bool SAL_CALL containsPoint( const css::awt::Point& aPoint ) throw (css::uno::RuntimeException, std::exception) override;
+ virtual css::uno::Reference< css::accessibility::XAccessible > SAL_CALL getAccessibleAtPoint( const css::awt::Point& aPoint ) throw (css::uno::RuntimeException, std::exception) override;
+ virtual css::awt::Rectangle SAL_CALL getBounds( ) throw (css::uno::RuntimeException, std::exception) override;
+ virtual css::awt::Point SAL_CALL getLocation( ) throw (css::uno::RuntimeException, std::exception) override;
+ virtual css::awt::Point SAL_CALL getLocationOnScreen( ) throw (css::uno::RuntimeException, std::exception) override;
+ virtual css::awt::Size SAL_CALL getSize( ) throw (css::uno::RuntimeException, std::exception) override;
+ virtual void SAL_CALL grabFocus( ) throw (css::uno::RuntimeException, std::exception) override;
+ virtual sal_Int32 SAL_CALL getForeground( ) throw (css::uno::RuntimeException, std::exception) override;
+ virtual sal_Int32 SAL_CALL getBackground( ) throw (css::uno::RuntimeException, std::exception) override;
// XServiceInfo
- virtual OUString SAL_CALL getImplementationName() throw (::com::sun::star::uno::RuntimeException, std::exception) override;
- virtual sal_Bool SAL_CALL supportsService (const OUString& sServiceName) throw (::com::sun::star::uno::RuntimeException, std::exception) override;
- virtual ::com::sun::star::uno::Sequence< OUString> SAL_CALL getSupportedServiceNames() throw (::com::sun::star::uno::RuntimeException, std::exception) override;
+ virtual OUString SAL_CALL getImplementationName() throw (css::uno::RuntimeException, std::exception) override;
+ virtual sal_Bool SAL_CALL supportsService (const OUString& sServiceName) throw (css::uno::RuntimeException, std::exception) override;
+ virtual css::uno::Sequence< OUString> SAL_CALL getSupportedServiceNames() throw (css::uno::RuntimeException, std::exception) override;
/** Set the current index in the accessibility parent
@@ -145,15 +145,15 @@ namespace accessibility
sal_Int32 GetParagraphIndex() const { return mnParagraphIndex; }
/// Calls all Listener objects to tell them the change. Don't hold locks when calling this!
- void FireEvent(const sal_Int16 nEventId, const ::com::sun::star::uno::Any& rNewValue = ::com::sun::star::uno::Any(), const ::com::sun::star::uno::Any& rOldValue = ::com::sun::star::uno::Any() ) const;
+ void FireEvent(const sal_Int16 nEventId, const css::uno::Any& rNewValue = css::uno::Any(), const css::uno::Any& rOldValue = css::uno::Any() ) const;
private:
AccessibleImageBullet( const AccessibleImageBullet& ) = delete;
AccessibleImageBullet& operator= ( const AccessibleImageBullet& ) = delete;
// syntactic sugar for FireEvent
- void GotPropertyEvent( const ::com::sun::star::uno::Any& rNewValue, const sal_Int16 nEventId ) const;
- void LostPropertyEvent( const ::com::sun::star::uno::Any& rOldValue, const sal_Int16 nEventId ) const;
+ void GotPropertyEvent( const css::uno::Any& rNewValue, const sal_Int16 nEventId ) const;
+ void LostPropertyEvent( const css::uno::Any& rOldValue, const sal_Int16 nEventId ) const;
// maintain state set and send STATE_CHANGE events
void SetState( const sal_Int16 nStateId );
@@ -196,10 +196,10 @@ namespace accessibility
Point maEEOffset;
// the current state set (updated from SetState/UnSetState and guarded by solar mutex)
- ::com::sun::star::uno::Reference< ::com::sun::star::accessibility::XAccessibleStateSet > mxStateSet;
+ css::uno::Reference< css::accessibility::XAccessibleStateSet > mxStateSet;
/// The shape we're the accessible for (unguarded)
- ::com::sun::star::uno::Reference< ::com::sun::star::accessibility::XAccessible > mxParent;
+ css::uno::Reference< css::accessibility::XAccessible > mxParent;
/// Our listeners (guarded by maMutex)
int mnNotifierClientId;
diff --git a/include/editeng/AccessibleParaManager.hxx b/include/editeng/AccessibleParaManager.hxx
index e9b26dd..e4684d2 100644
--- a/include/editeng/AccessibleParaManager.hxx
+++ b/include/editeng/AccessibleParaManager.hxx
@@ -52,7 +52,7 @@ namespace accessibility
typedef UnoType UnoInterfaceType;
typedef CppType InterfaceType;
- HardCppRef( const ::com::sun::star::uno::WeakReference< UnoInterfaceType >& xRef, InterfaceType* rImpl ) :
+ HardCppRef( const css::uno::WeakReference< UnoInterfaceType >& xRef, InterfaceType* rImpl ) :
mxRef( xRef ),
mpImpl( rImpl )
{
@@ -66,8 +66,8 @@ namespace accessibility
bool is() const { return mxRef.is(); }
InterfaceType* operator->() const { return mpImpl; }
InterfaceType& operator*() const { return *mpImpl; }
- ::com::sun::star::uno::Reference< UnoInterfaceType >& getRef() { return mxRef; }
- const ::com::sun::star::uno::Reference< UnoInterfaceType >& getRef() const { return mxRef; }
+ css::uno::Reference< UnoInterfaceType >& getRef() { return mxRef; }
+ const css::uno::Reference< UnoInterfaceType >& getRef() const { return mxRef; }
// default copy constructor and assignment will do
// HardCppRef( const HardCppRef& );
@@ -76,7 +76,7 @@ namespace accessibility
private:
// the interface, hard reference to prevent object from vanishing
- ::com::sun::star::uno::Reference< UnoInterfaceType > mxRef;
+ css::uno::Reference< UnoInterfaceType > mxRef;
// the c++ object, for our internal stuff
InterfaceType* mpImpl;
@@ -100,7 +100,7 @@ namespace accessibility
WeakCppRef() : maWeakRef(), maUnsafeRef( NULL ) {}
WeakCppRef( InterfaceType& rImpl ) :
- maWeakRef( ::com::sun::star::uno::Reference< UnoInterfaceType >( rImpl, ::com::sun::star::uno::UNO_QUERY ) ),
+ maWeakRef( css::uno::Reference< UnoInterfaceType >( rImpl, css::uno::UNO_QUERY ) ),
maUnsafeRef( &rImpl )
{
}
@@ -122,10 +122,10 @@ namespace accessibility
private:
// the interface, hold weakly
- ::com::sun::star::uno::WeakReference< UnoInterfaceType > maWeakRef;
+ css::uno::WeakReference< UnoInterfaceType > maWeakRef;
// hard ref to c++ class, _only_ valid if maWeakRef.is() is true
- InterfaceType* maUnsafeRef;
+ InterfaceType* maUnsafeRef;
};
@@ -137,10 +137,10 @@ namespace accessibility
class EDITENG_DLLPUBLIC AccessibleParaManager
{
public:
- typedef WeakCppRef < ::com::sun::star::accessibility::XAccessible, AccessibleEditableTextPara > WeakPara;
- typedef ::std::pair< WeakPara, ::com::sun::star::awt::Rectangle > WeakChild;
- typedef ::std::pair< ::com::sun::star::uno::Reference<
- ::com::sun::star::accessibility::XAccessible > , ::com::sun::star::awt::Rectangle > Child;
+ typedef WeakCppRef < css::accessibility::XAccessible, AccessibleEditableTextPara > WeakPara;
+ typedef ::std::pair< WeakPara, css::awt::Rectangle > WeakChild;
+ typedef ::std::pair< css::uno::Reference<
+ css::accessibility::XAccessible > , css::awt::Rectangle > Child;
typedef ::std::vector< WeakChild > VectorOfChildren;
typedef ::std::vector< sal_Int16 > VectorOfStates;
@@ -151,7 +151,7 @@ namespace accessibility
The states are passed to every created child object
(text paragraph). The state values are defined in
- com::sun::star::accessibility::AccessibleStateType.
+ css::accessibility::AccessibleStateType.
*/
void SetAdditionalChildStates( const VectorOfStates& rChildStates );
@@ -175,15 +175,15 @@ namespace accessibility
void FireEvent( sal_Int32 nPara,
const sal_Int16 nEventId,
- const ::com::sun::star::uno::Any& rNewValue = ::com::sun::star::uno::Any(),
- const ::com::sun::star::uno::Any& rOldValue = ::com::sun::star::uno::Any() ) const;
+ const css::uno::Any& rNewValue = css::uno::Any(),
+ const css::uno::Any& rOldValue = css::uno::Any() ) const;
static bool IsReferencable( WeakPara::HardRefType aChild );
bool IsReferencable( sal_Int32 nChild ) const;
static void ShutdownPara( const WeakChild& rChild );
Child CreateChild( sal_Int32 nChild,
- const ::com::sun::star::uno::Reference< ::com::sun::star::accessibility::XAccessible >& xFrontEnd,
+ const css::uno::Reference< css::accessibility::XAccessible >& xFrontEnd,
SvxEditSourceAdapter& rEditSource,
sal_Int32 nParagraphIndex );
@@ -228,8 +228,8 @@ namespace accessibility
void FireEvent( sal_Int32 nStartPara,
sal_Int32 nEndPara,
const sal_Int16 nEventId,
- const ::com::sun::star::uno::Any& rNewValue = ::com::sun::star::uno::Any(),
- const ::com::sun::star::uno::Any& rOldValue = ::com::sun::star::uno::Any() ) const;
+ const css::uno::Any& rNewValue = css::uno::Any(),
+ const css::uno::Any& rOldValue = css::uno::Any() ) const;
/** Functor adapter for ForEach template
diff --git a/include/editeng/AccessibleSelectionBase.hxx b/include/editeng/AccessibleSelectionBase.hxx
index 77ad1de..66bcf40 100644
--- a/include/editeng/AccessibleSelectionBase.hxx
+++ b/include/editeng/AccessibleSelectionBase.hxx
@@ -37,7 +37,7 @@ namespace accessibility
<method>implSelect</method>,
*/
class EDITENG_DLLPUBLIC AccessibleSelectionBase : public ::comphelper::OCommonAccessibleSelection,
- public ::com::sun::star::accessibility::XAccessibleSelection
+ public css::accessibility::XAccessibleSelection
{
protected:
@@ -46,13 +46,13 @@ namespace accessibility
public:
// XAccessibleSelection - default implementations
- virtual void SAL_CALL selectAccessibleChild( sal_Int32 nChildIndex ) throw (::com::sun::star::lang::IndexOutOfBoundsException, ::com::sun::star::uno::RuntimeException, std::exception) override;
- virtual sal_Bool SAL_CALL isAccessibleChildSelected( sal_Int32 nChildIndex ) throw (::com::sun::star::lang::IndexOutOfBoundsException, ::com::sun::star::uno::RuntimeException, std::exception) override;
- virtual void SAL_CALL clearAccessibleSelection( ) throw (::com::sun::star::uno::RuntimeException, std::exception) override;
- virtual void SAL_CALL selectAllAccessibleChildren( ) throw (::com::sun::star::uno::RuntimeException, std::exception) override;
- virtual sal_Int32 SAL_CALL getSelectedAccessibleChildCount( ) throw (::com::sun::star::uno::RuntimeException, std::exception) override;
- virtual ::com::sun::star::uno::Reference< ::com::sun::star::accessibility::XAccessible > SAL_CALL getSelectedAccessibleChild( sal_Int32 nSelectedChildIndex ) throw (::com::sun::star::lang::IndexOutOfBoundsException, ::com::sun::star::uno::RuntimeException, std::exception) override;
- virtual void SAL_CALL deselectAccessibleChild( sal_Int32 nSelectedChildIndex ) throw (::com::sun::star::lang::IndexOutOfBoundsException, ::com::sun::star::uno::RuntimeException, std::exception) override;
+ virtual void SAL_CALL selectAccessibleChild( sal_Int32 nChildIndex ) throw (css::lang::IndexOutOfBoundsException, css::uno::RuntimeException, std::exception) override;
+ virtual sal_Bool SAL_CALL isAccessibleChildSelected( sal_Int32 nChildIndex ) throw (css::lang::IndexOutOfBoundsException, css::uno::RuntimeException, std::exception) override;
+ virtual void SAL_CALL clearAccessibleSelection( ) throw (css::uno::RuntimeException, std::exception) override;
+ virtual void SAL_CALL selectAllAccessibleChildren( ) throw (css::uno::RuntimeException, std::exception) override;
+ virtual sal_Int32 SAL_CALL getSelectedAccessibleChildCount( ) throw (css::uno::RuntimeException, std::exception) override;
+ virtual css::uno::Reference< css::accessibility::XAccessible > SAL_CALL getSelectedAccessibleChild( sal_Int32 nSelectedChildIndex ) throw (css::lang::IndexOutOfBoundsException, css::uno::RuntimeException, std::exception) override;
+ virtual void SAL_CALL deselectAccessibleChild( sal_Int32 nSelectedChildIndex ) throw (css::lang::IndexOutOfBoundsException, css::uno::RuntimeException, std::exception) override;
public:
diff --git a/include/editeng/AccessibleStaticTextBase.hxx b/include/editeng/AccessibleStaticTextBase.hxx
index 46be379..54f0221 100644
--- a/include/editeng/AccessibleStaticTextBase.hxx
+++ b/include/editeng/AccessibleStaticTextBase.hxx
@@ -41,8 +41,8 @@ namespace accessibility
class AccessibleStaticTextBase_Impl;
typedef ::cppu::ImplHelper2<
- ::com::sun::star::accessibility::XAccessibleText,
- ::com::sun::star::accessibility::XAccessibleTextAttributes > AccessibleStaticTextBase_BASE;
+ css::accessibility::XAccessibleText,
+ css::accessibility::XAccessibleTextAttributes > AccessibleStaticTextBase_BASE;
/** Helper class for objects containing EditEngine/Outliner text
@@ -150,7 +150,7 @@ namespace accessibility
The interface that should be set as the source for
accessibility events sent by this object.
*/
- void SetEventSource( const ::com::sun::star::uno::Reference< ::com::sun::star::accessibility::XAccessible >& rInterface );
+ void SetEventSource( const css::uno::Reference< css::accessibility::XAccessible >& rInterface );
/** Set offset of EditEngine from parent
@@ -178,39 +178,39 @@ namespace accessibility
void Dispose();
// XAccessibleText interface implementation
- virtual sal_Int32 SAL_CALL getCaretPosition() throw (::com::sun::star::uno::RuntimeException, std::exception) override;
- virtual sal_Bool SAL_CALL setCaretPosition( sal_Int32 nIndex ) throw (::com::sun::star::lang::IndexOutOfBoundsException, ::com::sun::star::uno::RuntimeException, std::exception) override;
- virtual sal_Unicode SAL_CALL getCharacter( sal_Int32 nIndex ) throw (::com::sun::star::lang::IndexOutOfBoundsException, ::com::sun::star::uno::RuntimeException, std::exception) override;
- virtual ::com::sun::star::uno::Sequence< ::com::sun::star::beans::PropertyValue > SAL_CALL getCharacterAttributes( sal_Int32 nIndex, const ::com::sun::star::uno::Sequence< OUString >& aRequestedAttributes ) throw (::com::sun::star::lang::IndexOutOfBoundsException, ::com::sun::star::uno::RuntimeException, std::exception) override;
- virtual ::com::sun::star::awt::Rectangle SAL_CALL getCharacterBounds( sal_Int32 nIndex ) throw (::com::sun::star::lang::IndexOutOfBoundsException, ::com::sun::star::uno::RuntimeException, std::exception) override;
- virtual sal_Int32 SAL_CALL getCharacterCount() throw (::com::sun::star::uno::RuntimeException, std::exception) override;
- virtual sal_Int32 SAL_CALL getIndexAtPoint( const ::com::sun::star::awt::Point& aPoint ) throw (::com::sun::star::uno::RuntimeException, std::exception) override;
- virtual OUString SAL_CALL getSelectedText() throw (::com::sun::star::uno::RuntimeException, std::exception) override;
- virtual sal_Int32 SAL_CALL getSelectionStart() throw (::com::sun::star::uno::RuntimeException, std::exception) override;
- virtual sal_Int32 SAL_CALL getSelectionEnd() throw (::com::sun::star::uno::RuntimeException, std::exception) override;
+ virtual sal_Int32 SAL_CALL getCaretPosition() throw (css::uno::RuntimeException, std::exception) override;
+ virtual sal_Bool SAL_CALL setCaretPosition( sal_Int32 nIndex ) throw (css::lang::IndexOutOfBoundsException, css::uno::RuntimeException, std::exception) override;
+ virtual sal_Unicode SAL_CALL getCharacter( sal_Int32 nIndex ) throw (css::lang::IndexOutOfBoundsException, css::uno::RuntimeException, std::exception) override;
+ virtual css::uno::Sequence< css::beans::PropertyValue > SAL_CALL getCharacterAttributes( sal_Int32 nIndex, const css::uno::Sequence< OUString >& aRequestedAttributes ) throw (css::lang::IndexOutOfBoundsException, css::uno::RuntimeException, std::exception) override;
+ virtual css::awt::Rectangle SAL_CALL getCharacterBounds( sal_Int32 nIndex ) throw (css::lang::IndexOutOfBoundsException, css::uno::RuntimeException, std::exception) override;
+ virtual sal_Int32 SAL_CALL getCharacterCount() throw (css::uno::RuntimeException, std::exception) override;
+ virtual sal_Int32 SAL_CALL getIndexAtPoint( const css::awt::Point& aPoint ) throw (css::uno::RuntimeException, std::exception) override;
+ virtual OUString SAL_CALL getSelectedText() throw (css::uno::RuntimeException, std::exception) override;
+ virtual sal_Int32 SAL_CALL getSelectionStart() throw (css::uno::RuntimeException, std::exception) override;
+ virtual sal_Int32 SAL_CALL getSelectionEnd() throw (css::uno::RuntimeException, std::exception) override;
/// This will only work with a functional SvxEditViewForwarder, i.e. an EditEngine/Outliner in edit mode
- virtual sal_Bool SAL_CALL setSelection( sal_Int32 nStartIndex, sal_Int32 nEndIndex ) throw (::com::sun::star::lang::IndexOutOfBoundsException, ::com::sun::star::uno::RuntimeException, std::exception) override;
- virtual OUString SAL_CALL getText() throw (::com::sun::star::uno::RuntimeException, std::exception) override;
- virtual OUString SAL_CALL getTextRange( sal_Int32 nStartIndex, sal_Int32 nEndIndex ) throw (::com::sun::star::lang::IndexOutOfBoundsException, ::com::sun::star::uno::RuntimeException, std::exception) override;
+ virtual sal_Bool SAL_CALL setSelection( sal_Int32 nStartIndex, sal_Int32 nEndIndex ) throw (css::lang::IndexOutOfBoundsException, css::uno::RuntimeException, std::exception) override;
+ virtual OUString SAL_CALL getText() throw (css::uno::RuntimeException, std::exception) override;
+ virtual OUString SAL_CALL getTextRange( sal_Int32 nStartIndex, sal_Int32 nEndIndex ) throw (css::lang::IndexOutOfBoundsException, css::uno::RuntimeException, std::exception) override;
/// Does not support AccessibleTextType::SENTENCE (missing feature in EditEngine)
- virtual ::com::sun::star::accessibility::TextSegment SAL_CALL getTextAtIndex( sal_Int32 nIndex, sal_Int16 aTextType ) throw (::com::sun::star::lang::IndexOutOfBoundsException, ::com::sun::star::lang::IllegalArgumentException, ::com::sun::star::uno::RuntimeException, std::exception) override;
+ virtual css::accessibility::TextSegment SAL_CALL getTextAtIndex( sal_Int32 nIndex, sal_Int16 aTextType ) throw (css::lang::IndexOutOfBoundsException, css::lang::IllegalArgumentException, css::uno::RuntimeException, std::exception) override;
/// Does not support AccessibleTextType::SENTENCE (missing feature in EditEngine)
- virtual ::com::sun::star::accessibility::TextSegment SAL_CALL getTextBeforeIndex( sal_Int32 nIndex, sal_Int16 aTextType ) throw (::com::sun::star::lang::IndexOutOfBoundsException, ::com::sun::star::lang::IllegalArgumentException, ::com::sun::star::uno::RuntimeException, std::exception) override;
+ virtual css::accessibility::TextSegment SAL_CALL getTextBeforeIndex( sal_Int32 nIndex, sal_Int16 aTextType ) throw (css::lang::IndexOutOfBoundsException, css::lang::IllegalArgumentException, css::uno::RuntimeException, std::exception) override;
/// Does not support AccessibleTextType::SENTENCE (missing feature in EditEngine)
- virtual ::com::sun::star::accessibility::TextSegment SAL_CALL getTextBehindIndex( sal_Int32 nIndex, sal_Int16 aTextType ) throw (::com::sun::star::lang::IndexOutOfBoundsException, ::com::sun::star::lang::IllegalArgumentException, ::com::sun::star::uno::RuntimeException, std::exception) override;
+ virtual css::accessibility::TextSegment SAL_CALL getTextBehindIndex( sal_Int32 nIndex, sal_Int16 aTextType ) throw (css::lang::IndexOutOfBoundsException, css::lang::IllegalArgumentException, css::uno::RuntimeException, std::exception) override;
/// This will only work with a functional SvxEditViewForwarder, i.e. an EditEngine/Outliner in edit mode
- virtual sal_Bool SAL_CALL copyText( sal_Int32 nStartIndex, sal_Int32 nEndIndex ) throw (::com::sun::star::lang::IndexOutOfBoundsException, ::com::sun::star::uno::RuntimeException, std::exception) override;
+ virtual sal_Bool SAL_CALL copyText( sal_Int32 nStartIndex, sal_Int32 nEndIndex ) throw (css::lang::IndexOutOfBoundsException, css::uno::RuntimeException, std::exception) override;
// XAccessibleTextAttributes
- virtual ::com::sun::star::uno::Sequence< ::com::sun::star::beans::PropertyValue > SAL_CALL getDefaultAttributes( const ::com::sun::star::uno::Sequence< OUString >& RequestedAttributes ) throw (::com::sun::star::uno::RuntimeException, std::exception) override;
- virtual ::com::sun::star::uno::Sequence< ::com::sun::star::beans::PropertyValue > SAL_CALL getRunAttributes( sal_Int32 Index, const ::com::sun::star::uno::Sequence< OUString >& RequestedAttributes ) throw (::com::sun::star::lang::IndexOutOfBoundsException, ::com::sun::star::uno::RuntimeException, std::exception) override;
+ virtual css::uno::Sequence< css::beans::PropertyValue > SAL_CALL getDefaultAttributes( const css::uno::Sequence< OUString >& RequestedAttributes ) throw (css::uno::RuntimeException, std::exception) override;
+ virtual css::uno::Sequence< css::beans::PropertyValue > SAL_CALL getRunAttributes( sal_Int32 Index, const css::uno::Sequence< OUString >& RequestedAttributes ) throw (css::lang::IndexOutOfBoundsException, css::uno::RuntimeException, std::exception) override;
// child-related methods from XAccessibleContext
- virtual sal_Int32 SAL_CALL getAccessibleChildCount() throw (::com::sun::star::uno::RuntimeException, std::exception);
- virtual ::com::sun::star::uno::Reference< ::com::sun::star::accessibility::XAccessible > SAL_CALL getAccessibleChild( sal_Int32 i ) throw (::com::sun::star::lang::IndexOutOfBoundsException, ::com::sun::star::uno::RuntimeException, std::exception);
+ virtual sal_Int32 SAL_CALL getAccessibleChildCount() throw (css::uno::RuntimeException, std::exception);
+ virtual css::uno::Reference< css::accessibility::XAccessible > SAL_CALL getAccessibleChild( sal_Int32 i ) throw (css::lang::IndexOutOfBoundsException, css::uno::RuntimeException, std::exception);
// child-related methods from XAccessibleComponent
- virtual ::com::sun::star::uno::Reference< ::com::sun::star::accessibility::XAccessible > SAL_CALL getAccessibleAtPoint( const ::com::sun::star::awt::Point& aPoint ) throw (::com::sun::star::uno::RuntimeException, std::exception);
+ virtual css::uno::Reference< css::accessibility::XAccessible > SAL_CALL getAccessibleAtPoint( const css::awt::Point& aPoint ) throw (css::uno::RuntimeException, std::exception);
protected:
Rectangle GetParagraphBoundingBox() const;
diff --git a/include/editeng/SpellPortions.hxx b/include/editeng/SpellPortions.hxx
index 9cb158d..bdf1207 100644
--- a/include/editeng/SpellPortions.hxx
+++ b/include/editeng/SpellPortions.hxx
@@ -55,16 +55,16 @@ struct SpellPortion
/** for wrong words this reference is filled with the error information otherwise
it's an empty reference
*/
- ::com::sun::star::uno::Reference< ::com::sun::star::linguistic2::XSpellAlternatives> xAlternatives;
+ css::uno::Reference< css::linguistic2::XSpellAlternatives> xAlternatives;
/** determines whether the error type is a grammar error
*/
bool bIsGrammarError;
/** contains the grammar error information
*/
- com::sun::star::linguistic2::SingleProofreadingError aGrammarError;
+ css::linguistic2::SingleProofreadingError aGrammarError;
/** provides access to the grammar checker interface
*/
- ::com::sun::star::uno::Reference< ::com::sun::star::linguistic2::XProofreader > xGrammarChecker;
+ css::uno::Reference< css::linguistic2::XProofreader > xGrammarChecker;
/** marks portion as to-be-ignored. This is a return parameter.
*/
/** contains the proposed dialog title if the proof reading component provides one.
diff --git a/include/editeng/UnoForbiddenCharsTable.hxx b/include/editeng/UnoForbiddenCharsTable.hxx
index 3626f73..defcb74 100644
--- a/include/editeng/UnoForbiddenCharsTable.hxx
+++ b/include/editeng/UnoForbiddenCharsTable.hxx
@@ -30,8 +30,8 @@
class SvxForbiddenCharactersTable;
class EDITENG_DLLPUBLIC SvxUnoForbiddenCharsTable : public cppu::WeakImplHelper<
- com::sun::star::i18n::XForbiddenCharacters,
- com::sun::star::linguistic2::XSupportedLocales>
+ css::i18n::XForbiddenCharacters,
+ css::linguistic2::XSupportedLocales>
{
protected:
/** this virtual function is called if the forbidden characters are changed */
@@ -44,14 +44,14 @@ public:
virtual ~SvxUnoForbiddenCharsTable();
// XForbiddenCharacters
- virtual com::sun::star::i18n::ForbiddenCharacters SAL_CALL getForbiddenCharacters( const com::sun::star::lang::Locale& rLocale ) throw(com::sun::star::container::NoSuchElementException, com::sun::star::uno::RuntimeException, std::exception) override;
- virtual sal_Bool SAL_CALL hasForbiddenCharacters( const com::sun::star::lang::Locale& rLocale ) throw(com::sun::star::uno::RuntimeException, std::exception) override;
- virtual void SAL_CALL setForbiddenCharacters( const com::sun::star::lang::Locale& rLocale, const com::sun::star::i18n::ForbiddenCharacters& rForbiddenCharacters ) throw(com::sun::star::uno::RuntimeException, std::exception) override;
- virtual void SAL_CALL removeForbiddenCharacters( const com::sun::star::lang::Locale& rLocale ) throw(com::sun::star::uno::RuntimeException, std::exception) override;
+ virtual css::i18n::ForbiddenCharacters SAL_CALL getForbiddenCharacters( const css::lang::Locale& rLocale ) throw(css::container::NoSuchElementException, css::uno::RuntimeException, std::exception) override;
+ virtual sal_Bool SAL_CALL hasForbiddenCharacters( const css::lang::Locale& rLocale ) throw(css::uno::RuntimeException, std::exception) override;
+ virtual void SAL_CALL setForbiddenCharacters( const css::lang::Locale& rLocale, const css::i18n::ForbiddenCharacters& rForbiddenCharacters ) throw(css::uno::RuntimeException, std::exception) override;
+ virtual void SAL_CALL removeForbiddenCharacters( const css::lang::Locale& rLocale ) throw(css::uno::RuntimeException, std::exception) override;
// XSupportedLocales
- virtual ::com::sun::star::uno::Sequence< ::com::sun::star::lang::Locale > SAL_CALL getLocales( ) throw (::com::sun::star::uno::RuntimeException, std::exception) override;
- virtual sal_Bool SAL_CALL hasLocale( const ::com::sun::star::lang::Locale& aLocale ) throw (::com::sun::star::uno::RuntimeException, std::exception) override;
+ virtual css::uno::Sequence< css::lang::Locale > SAL_CALL getLocales( ) throw (css::uno::RuntimeException, std::exception) override;
+ virtual sal_Bool SAL_CALL hasLocale( const css::lang::Locale& aLocale ) throw (css::uno::RuntimeException, std::exception) override;
};
#endif // INCLUDED_EDITENG_UNOFORBIDDENCHARSTABLE_HXX
diff --git a/include/editeng/acorrcfg.hxx b/include/editeng/acorrcfg.hxx
index b97b298..855eb55 100644
--- a/include/editeng/acorrcfg.hxx
+++ b/include/editeng/acorrcfg.hxx
@@ -28,7 +28,7 @@ class EDITENG_DLLPUBLIC SvxBaseAutoCorrCfg : public utl::ConfigItem
{
private:
SvxAutoCorrCfg& rParent;
- static com::sun::star::uno::Sequence<OUString> GetPropertyNames();
+ static css::uno::Sequence<OUString> GetPropertyNames();
virtual void ImplCommit() override;
@@ -37,7 +37,7 @@ public:
virtual ~SvxBaseAutoCorrCfg();
void Load(bool bInit);
- virtual void Notify( const com::sun::star::uno::Sequence<OUString>& aPropertyNames) override;
+ virtual void Notify( const css::uno::Sequence<OUString>& aPropertyNames) override;
void SetModified() {ConfigItem::SetModified();}
};
@@ -45,7 +45,7 @@ class EDITENG_DLLPUBLIC SvxSwAutoCorrCfg : public utl::ConfigItem
{
private:
SvxAutoCorrCfg& rParent;
- static com::sun::star::uno::Sequence<OUString> GetPropertyNames();
+ static css::uno::Sequence<OUString> GetPropertyNames();
virtual void ImplCommit() override;
@@ -54,7 +54,7 @@ public:
virtual ~SvxSwAutoCorrCfg();
void Load(bool bInit);
- virtual void Notify( const com::sun::star::uno::Sequence<OUString>& aPropertyNames) override;
+ virtual void Notify( const css::uno::Sequence<OUString>& aPropertyNames) override;
void SetModified() {ConfigItem::SetModified();}
};
/*--------------------------------------------------------------------
diff --git a/include/editeng/adjustitem.hxx b/include/editeng/adjustitem.hxx
index 643d321..6500a0c 100644
--- a/include/editeng/adjustitem.hxx
+++ b/include/editeng/adjustitem.hxx
@@ -55,15 +55,15 @@ public:
// "pure virtual Methods" from SfxPoolItem
virtual bool operator==( const SfxPoolItem& ) const override;
- virtual bool QueryValue( com::sun::star::uno::Any& rVal, sal_uInt8 nMemberId = 0 ) const override;
- virtual bool PutValue( const com::sun::star::uno::Any& rVal, sal_uInt8 nMemberId ) override;
+ virtual bool QueryValue( css::uno::Any& rVal, sal_uInt8 nMemberId = 0 ) const override;
+ virtual bool PutValue( const css::uno::Any& rVal, sal_uInt8 nMemberId ) override;
virtual bool GetPresentation( SfxItemPresentation ePres,
SfxMapUnit eCoreMetric,
SfxMapUnit ePresMetric,
OUString &rText, const IntlWrapper * = 0 ) const override;
virtual sal_uInt16 GetValueCount() const override;
- virtual OUString GetValueTextByPos( sal_uInt16 nPos ) const override;
+ virtual OUString GetValueTextByPos( sal_uInt16 nPos ) const override;
virtual sal_uInt16 GetEnumValue() const override;
virtual void SetEnumValue( sal_uInt16 nNewVal ) override;
virtual SfxPoolItem* Clone( SfxItemPool *pPool = 0 ) const override;
diff --git a/include/editeng/borderline.hxx b/include/editeng/borderline.hxx
index 1afc403..5fbe55f 100644
--- a/include/editeng/borderline.hxx
+++ b/include/editeng/borderline.hxx
@@ -40,7 +40,7 @@
namespace editeng {
- // values from ::com::sun::star::table::BorderLineStyle
+ // values from css::table::BorderLineStyle
typedef sal_Int16 SvxBorderStyle;
// convert border style between Word formats and LO
@@ -70,8 +70,8 @@ namespace editeng {
public:
SvxBorderLine( const Color *pCol = 0,
- long nWidth = 0, SvxBorderStyle nStyle =
- ::com::sun::star::table::BorderLineStyle::SOLID,
+ long nWidth = 0,
+ SvxBorderStyle nStyle = css::table::BorderLineStyle::SOLID,
bool bUseLeftTop = false,
Color (*pColorOutFn)( Color ) = &darkColor,
Color (*pColorInFn)( Color ) = &darkColor,
@@ -137,7 +137,7 @@ namespace editeng {
bool isEmpty() const {
return m_aWidthImpl.IsEmpty()
- || m_nStyle == ::com::sun::star::table::BorderLineStyle::NONE
+ || m_nStyle == css::table::BorderLineStyle::NONE
|| m_nWidth == 0;
}
bool isDouble() const { return m_aWidthImpl.IsDouble(); }
diff --git a/include/editeng/boxitem.hxx b/include/editeng/boxitem.hxx
index a62e47e..c8533fc 100644
--- a/include/editeng/boxitem.hxx
+++ b/include/editeng/boxitem.hxx
@@ -71,8 +71,8 @@ public:
// "pure virtual Methods" from SfxPoolItem
virtual bool operator==( const SfxPoolItem& ) const override;
- virtual bool QueryValue( com::sun::star::uno::Any& rVal, sal_uInt8 nMemberId = 0 ) const override;
- virtual bool PutValue( const com::sun::star::uno::Any& rVal, sal_uInt8 nMemberId ) override;
+ virtual bool QueryValue( css::uno::Any& rVal, sal_uInt8 nMemberId = 0 ) const override;
+ virtual bool PutValue( const css::uno::Any& rVal, sal_uInt8 nMemberId ) override;
virtual bool GetPresentation( SfxItemPresentation ePres,
SfxMapUnit eCoreMetric,
@@ -106,9 +106,9 @@ public:
// Line width plus Space plus inward distance
// bIgnoreLine = TRUE -> Also return distance, when no Line is set
sal_uInt16 CalcLineSpace( SvxBoxItemLine nLine, bool bIgnoreLine = false ) const;
- static com::sun::star::table::BorderLine2 SvxLineToLine( const editeng::SvxBorderLine* pLine, bool bConvert );
- static bool LineToSvxLine(const ::com::sun::star::table::BorderLine& rLine, editeng::SvxBorderLine& rSvxLine, bool bConvert);
- static bool LineToSvxLine(const ::com::sun::star::table::BorderLine2& rLine, editeng::SvxBorderLine& rSvxLine, bool bConvert);
+ static css::table::BorderLine2 SvxLineToLine( const editeng::SvxBorderLine* pLine, bool bConvert );
+ static bool LineToSvxLine(const css::table::BorderLine& rLine, editeng::SvxBorderLine& rSvxLine, bool bConvert);
+ static bool LineToSvxLine(const css::table::BorderLine2& rLine, editeng::SvxBorderLine& rSvxLine, bool bConvert);
};
inline void SvxBoxItem::SetDistance( sal_uInt16 nNew )
@@ -187,8 +187,8 @@ public:
SfxMapUnit eCoreMetric,
SfxMapUnit ePresMetric,
OUString &rText, const IntlWrapper * = 0 ) const override;
- virtual bool QueryValue( com::sun::star::uno::Any& rVal, sal_uInt8 nMemberId = 0 ) const override;
- virtual bool PutValue( const com::sun::star::uno::Any& rVal, sal_uInt8 nMemberId ) override;
+ virtual bool QueryValue( css::uno::Any& rVal, sal_uInt8 nMemberId = 0 ) const override;
+ virtual bool PutValue( const css::uno::Any& rVal, sal_uInt8 nMemberId ) override;
virtual SfxPoolItem* Clone( SfxItemPool *pPool = 0 ) const override;
virtual SfxPoolItem* Create(SvStream &, sal_uInt16) const override;
diff --git a/include/editeng/brushitem.hxx b/include/editeng/brushitem.hxx
index dae8dde..6d0e1ee 100644
--- a/include/editeng/brushitem.hxx
+++ b/include/editeng/brushitem.hxx
@@ -82,8 +82,8 @@ public:
OUString &rText, const IntlWrapper * = 0 ) const override;
virtual bool operator==( const SfxPoolItem& ) const override;
- virtual bool QueryValue( com::sun::star::uno::Any& rVal, sal_uInt8 nMemberId = 0 ) const override;
- virtual bool PutValue( const com::sun::star::uno::Any& rVal, sal_uInt8 nMemberId ) override;
+ virtual bool QueryValue( css::uno::Any& rVal, sal_uInt8 nMemberId = 0 ) const override;
+ virtual bool PutValue( const css::uno::Any& rVal, sal_uInt8 nMemberId ) override;
virtual SfxPoolItem* Clone( SfxItemPool *pPool = 0 ) const override;
virtual SfxPoolItem* Create( SvStream&, sal_uInt16 nVersion ) const override;
diff --git a/include/editeng/charreliefitem.hxx b/include/editeng/charreliefitem.hxx
index 88c2a35..979fe57 100644
--- a/include/editeng/charreliefitem.hxx
+++ b/include/editeng/charreliefitem.hxx
@@ -53,8 +53,8 @@ public:
OUString &rText,
const IntlWrapper * = 0 ) const override;
- virtual bool QueryValue( com::sun::star::uno::Any& rVal, sal_uInt8 nMemberId = 0 ) const override;
- virtual bool PutValue( const com::sun::star::uno::Any& rVal, sal_uInt8 nMemberId ) override;
+ virtual bool QueryValue( css::uno::Any& rVal, sal_uInt8 nMemberId = 0 ) const override;
+ virtual bool PutValue( const css::uno::Any& rVal, sal_uInt8 nMemberId ) override;
inline SvxCharReliefItem& operator=( const SvxCharReliefItem& rItem )
{
diff --git a/include/editeng/charrotateitem.hxx b/include/editeng/charrotateitem.hxx
index 8105693..bededa4 100644
--- a/include/editeng/charrotateitem.hxx
+++ b/include/editeng/charrotateitem.hxx
@@ -54,8 +54,8 @@ public:
OUString &rText,
const IntlWrapper * = 0 ) const override;
- virtual bool QueryValue( com::sun::star::uno::Any& rVal, sal_uInt8 nMemberId = 0 ) const override;
- virtual bool PutValue( const com::sun::star::uno::Any& rVal, sal_uInt8 nMemberId ) override;
+ virtual bool QueryValue( css::uno::Any& rVal, sal_uInt8 nMemberId = 0 ) const override;
+ virtual bool PutValue( const css::uno::Any& rVal, sal_uInt8 nMemberId ) override;
inline SvxCharRotateItem& operator=( const SvxCharRotateItem& rItem )
{
diff --git a/include/editeng/charscaleitem.hxx b/include/editeng/charscaleitem.hxx
index 0bc669d..e8a0738 100644
--- a/include/editeng/charscaleitem.hxx
+++ b/include/editeng/charscaleitem.hxx
@@ -51,8 +51,8 @@ public:
OUString &rText,
const IntlWrapper * = 0 ) const override;
- virtual bool QueryValue( com::sun::star::uno::Any& rVal, sal_uInt8 nMemberId = 0 ) const override;
- virtual bool PutValue( const com::sun::star::uno::Any& rVal, sal_uInt8 nMemberId ) override;
+ virtual bool QueryValue( css::uno::Any& rVal, sal_uInt8 nMemberId = 0 ) const override;
+ virtual bool PutValue( const css::uno::Any& rVal, sal_uInt8 nMemberId ) override;
inline SvxCharScaleWidthItem& operator=(const SvxCharScaleWidthItem& rItem )
{
diff --git a/include/editeng/cmapitem.hxx b/include/editeng/cmapitem.hxx
index 2ae2779..0e20f08 100644
--- a/include/editeng/cmapitem.hxx
+++ b/include/editeng/cmapitem.hxx
@@ -65,8 +65,8 @@ public:
// enum cast
SvxCaseMap GetCaseMap() const
{ return (SvxCaseMap)GetValue(); }
- virtual bool QueryValue( com::sun::star::uno::Any& rVal, sal_uInt8 nMemberId = 0 ) const override;
- virtual bool PutValue( const com::sun::star::uno::Any& rVal, sal_uInt8 nMemberId ) override;
+ virtual bool QueryValue( css::uno::Any& rVal, sal_uInt8 nMemberId = 0 ) const override;
+ virtual bool PutValue( const css::uno::Any& rVal, sal_uInt8 nMemberId ) override;
};
#endif
diff --git a/include/editeng/crossedoutitem.hxx b/include/editeng/crossedoutitem.hxx
index 98c24ef..9f0af96 100644
--- a/include/editeng/crossedoutitem.hxx
+++ b/include/editeng/crossedoutitem.hxx
@@ -48,10 +48,10 @@ public:
virtual SfxPoolItem* Clone( SfxItemPool *pPool = 0 ) const override;
virtual SfxPoolItem* Create(SvStream &, sal_uInt16) const override;
virtual SvStream& Store(SvStream &, sal_uInt16 nItemVersion) const override;
- virtual OUString GetValueTextByPos( sal_uInt16 nPos ) const override;
+ virtual OUString GetValueTextByPos( sal_uInt16 nPos ) const override;
virtual sal_uInt16 GetValueCount() const override;
- virtual bool QueryValue( com::sun::star::uno::Any& rVal, sal_uInt8 nMemberId = 0 ) const override;
- virtual bool PutValue( const com::sun::star::uno::Any& rVal, sal_uInt8 nMemberId ) override;
+ virtual bool QueryValue( css::uno::Any& rVal, sal_uInt8 nMemberId = 0 ) const override;
+ virtual bool PutValue( const css::uno::Any& rVal, sal_uInt8 nMemberId ) override;
// MS VC4.0 messes things up
void SetValue( sal_uInt16 nNewVal )
diff --git a/include/editeng/editeng.hxx b/include/editeng/editeng.hxx
index da46fe6..5f9779d 100644
--- a/include/editeng/editeng.hxx
+++ b/include/editeng/editeng.hxx
@@ -169,22 +169,22 @@ private:
EDITENG_DLLPRIVATE const ParaPortion* FindParaPortion(ContentNode* pNode) const;
EDITENG_DLLPRIVATE const ParaPortion* GetPrevVisPortion(const ParaPortion* pCurPortion) const;
- EDITENG_DLLPRIVATE com::sun::star::uno::Reference<
- com::sun::star::datatransfer::XTransferable>
+ EDITENG_DLLPRIVATE css::uno::Reference<
+ css::datatransfer::XTransferable>
CreateTransferable(const EditSelection& rSelection);
EDITENG_DLLPRIVATE EditSelection InsertText(
- com::sun::star::uno::Reference<com::sun::star::datatransfer::XTransferable >& rxDataObj,
+ css::uno::Reference<css::datatransfer::XTransferable >& rxDataObj,
const OUString& rBaseURL, const EditPaM& rPaM, bool bUseSpecial);
EDITENG_DLLPRIVATE EditPaM EndOfWord(
- const EditPaM& rPaM, sal_Int16 nWordType = com::sun::star::i18n::WordType::ANYWORD_IGNOREWHITESPACES);
+ const EditPaM& rPaM, sal_Int16 nWordType = css::i18n::WordType::ANYWORD_IGNOREWHITESPACES);
EDITENG_DLLPRIVATE EditPaM GetPaM(const Point& aDocPos, bool bSmart = true);
EDITENG_DLLPRIVATE EditSelection SelectWord(
const EditSelection& rCurSelection,
... etc. - the rest is truncated
More information about the Libreoffice-commits
mailing list
diff --git a/include/editeng/AccessibleComponentBase.hxx b/include/editeng/AccessibleComponentBase.hxx
index 1afc289..929de95 100644
--- a/include/editeng/AccessibleComponentBase.hxx
+++ b/include/editeng/AccessibleComponentBase.hxx
@@ -39,7 +39,7 @@ namespace accessibility {
XServiceInfo, and <type>XTypeProvider</type>.
*/
class EDITENG_DLLPUBLIC AccessibleComponentBase
- : public ::com::sun::star::accessibility::XAccessibleExtendedComponent
+ : public css::accessibility::XAccessibleExtendedComponent
{
public:
//===== internal ========================================================
@@ -54,83 +54,82 @@ public:
inside this object.
*/
virtual sal_Bool SAL_CALL containsPoint (
- const ::com::sun::star::awt::Point& aPoint)
- throw (::com::sun::star::uno::RuntimeException, std::exception) override;
+ const css::awt::Point& aPoint)
+ throw (css::uno::RuntimeException, std::exception) override;
/** The default implementation returns an empty reference.
*/
- virtual ::com::sun::star::uno::Reference<
- ::com::sun::star::accessibility::XAccessible > SAL_CALL
+ virtual css::uno::Reference< css::accessibility::XAccessible > SAL_CALL
getAccessibleAtPoint (
- const ::com::sun::star::awt::Point& aPoint)
- throw (::com::sun::star::uno::RuntimeException, std::exception) override;
+ const css::awt::Point& aPoint)
+ throw (css::uno::RuntimeException, std::exception) override;
/** The default implementation returns an empty rectangle.
*/
- virtual ::com::sun::star::awt::Rectangle SAL_CALL getBounds()
- throw (::com::sun::star::uno::RuntimeException, std::exception) override;
+ virtual css::awt::Rectangle SAL_CALL getBounds()
+ throw (css::uno::RuntimeException, std::exception) override;
/** The default implementation uses the result of
<member>getBounds</member> to determine the location.
*/
- virtual ::com::sun::star::awt::Point SAL_CALL getLocation()
- throw (::com::sun::star::uno::RuntimeException, std::exception) override;
+ virtual css::awt::Point SAL_CALL getLocation()
+ throw (css::uno::RuntimeException, std::exception) override;
/** The default implementation returns an empty position, i.e. the
* result of the default constructor of com::sun::star::awt::Point.
*/
- virtual ::com::sun::star::awt::Point SAL_CALL getLocationOnScreen()
- throw (::com::sun::star::uno::RuntimeException, std::exception) override;
+ virtual css::awt::Point SAL_CALL getLocationOnScreen()
+ throw (css::uno::RuntimeException, std::exception) override;
/** The default implementation uses the result of
<member>getBounds</member> to determine the size.
*/
- virtual ::com::sun::star::awt::Size SAL_CALL getSize()
- throw (::com::sun::star::uno::RuntimeException, std::exception) override;
+ virtual css::awt::Size SAL_CALL getSize()
+ throw (css::uno::RuntimeException, std::exception) override;
/** The default implementation ignores this call.
*/
virtual void SAL_CALL addFocusListener (
- const ::com::sun::star::uno::Reference<
- ::com::sun::star::awt::XFocusListener >& xListener)
- throw (::com::sun::star::uno::RuntimeException);
+ const css::uno::Reference<
+ css::awt::XFocusListener >& xListener)
+ throw (css::uno::RuntimeException);
/** The default implementation ignores this call.
*/
- virtual void SAL_CALL removeFocusListener (const ::com::sun::star::uno::Reference<
- ::com::sun::star::awt::XFocusListener >& xListener )
- throw (::com::sun::star::uno::RuntimeException);
+ virtual void SAL_CALL removeFocusListener (const css::uno::Reference<
+ css::awt::XFocusListener >& xListener )
+ throw (css::uno::RuntimeException);
/** The default implementation does nothing.
*/
virtual void SAL_CALL grabFocus()
- throw (::com::sun::star::uno::RuntimeException, std::exception) override;
+ throw (css::uno::RuntimeException, std::exception) override;
/** Returns black as the default foreground color.
*/
virtual sal_Int32 SAL_CALL getForeground()
- throw (::com::sun::star::uno::RuntimeException, std::exception) override;
+ throw (css::uno::RuntimeException, std::exception) override;
/** Returns white as the default background color.
*/
virtual sal_Int32 SAL_CALL getBackground()
- throw (::com::sun::star::uno::RuntimeException, std::exception) override;
+ throw (css::uno::RuntimeException, std::exception) override;
//===== XAccessibleExtendedComponent ====================================
- virtual ::com::sun::star::uno::Reference< ::com::sun::star::awt::XFont > SAL_CALL
+ virtual css::uno::Reference< css::awt::XFont > SAL_CALL
getFont()
- throw (::com::sun::star::uno::RuntimeException, std::exception) override;
+ throw (css::uno::RuntimeException, std::exception) override;
virtual OUString SAL_CALL getTitledBorderText()
- throw (::com::sun::star::uno::RuntimeException, std::exception) override;
+ throw (css::uno::RuntimeException, std::exception) override;
virtual OUString SAL_CALL getToolTipText()
- throw (::com::sun::star::uno::RuntimeException, std::exception) override;
+ throw (css::uno::RuntimeException, std::exception) override;
//===== XTypeProvider ===================================================
- virtual ::com::sun::star::uno::Sequence< ::com::sun::star::uno::Type> SAL_CALL
+ virtual css::uno::Sequence< css::uno::Type> SAL_CALL
getTypes()
- throw (::com::sun::star::uno::RuntimeException, std::exception);
+ throw (css::uno::RuntimeException, std::exception);
};
@@ -54,83 +54,82 @@ public:
/** The default implementation returns an empty position, i.e. the
- * result of the default constructor of com::sun::star::awt::Point.
+ * result of the default constructor of css::awt::Point.
*/